@@ -31,6 +31,7 @@ import org.apache.hadoop.security.UserGroupInformation;
 import org.apache.ranger.admin.client.datatype.RESTResponse;
 import org.apache.ranger.audit.provider.MiscUtil;
 import org.apache.ranger.authorization.hadoop.config.RangerConfiguration;
+import org.apache.ranger.authorization.utils.StringUtil;
 import org.apache.ranger.plugin.util.GrantRevokeRequest;
 import org.apache.ranger.plugin.util.RangerRESTClient;
 import org.apache.ranger.plugin.util.RangerRESTUtils;
@@ -47,15 +48,12 @@ import java.util.List;
 public class RangerAdminRESTClient implements RangerAdminClient {
 	private static final Log LOG = LogFactory.getLog(RangerAdminRESTClient.class);
 
-	private String           serviceName = null;
-	private String           pluginId    = null;
-	private RangerRESTClient restClient  = null;
-	private String clusterName = null;
+	private String           serviceName;
+	private String           pluginId;
+	private String clusterName;
+	private RangerRESTClient restClient;
 	private RangerRESTUtils restUtils   = new RangerRESTUtils();
 
-	public RangerAdminRESTClient() {
-	}
-
 	public static <T> GenericType<List<T>> getGenericType(final T clazz) {
 
 		ParameterizedType parameterizedGenericType = new ParameterizedType() {
@@ -80,11 +78,18 @@ public class RangerAdminRESTClient implements RangerAdminClient {
 		this.serviceName = serviceName;
 		this.pluginId    = restUtils.getPluginId(serviceName, appId);
 
-		String url               		= RangerConfiguration.getInstance().get(propertyPrefix + ".policy.rest.url");
+		String url                      = "";
+		String tmpUrl                   = RangerConfiguration.getInstance().get(propertyPrefix + ".policy.rest.url");
 		String sslConfigFileName 		= RangerConfiguration.getInstance().get(propertyPrefix + ".policy.rest.ssl.config.file");
 		clusterName       				= RangerConfiguration.getInstance().get(propertyPrefix + ".ambari.cluster.name", "");
 		int	 restClientConnTimeOutMs	= RangerConfiguration.getInstance().getInt(propertyPrefix + ".policy.rest.client.connection.timeoutMs", 120 * 1000);
 		int	 restClientReadTimeOutMs	= RangerConfiguration.getInstance().getInt(propertyPrefix + ".policy.rest.client.read.timeoutMs", 30 * 1000);
+        if (!StringUtil.isEmpty(tmpUrl)) {
+            url = tmpUrl.trim();
+        }
+        if (url.endsWith("/")) {
+            url = url.substring(0, url.length() - 1);
+        }
 
 		init(url, sslConfigFileName, restClientConnTimeOutMs , restClientReadTimeOutMs);
 	}
@@ -98,7 +103,6 @@ public class RangerAdminRESTClient implements RangerAdminClient {
 		ServicePolicies ret = null;
 		UserGroupInformation user = MiscUtil.getUGILoginUser();
 		boolean isSecureMode = user != null && UserGroupInformation.isSecurityEnabled();
-
 		ClientResponse response = null;
 		if (isSecureMode) {
 			if (LOG.isDebugEnabled()) {
@@ -133,7 +137,7 @@ public class RangerAdminRESTClient implements RangerAdminClient {
 			} else {
 				RESTResponse resp = RESTResponse.fromClientResponse(response);
 				if (LOG.isDebugEnabled()) {
-					LOG.debug("No change in policies. secureMode=" + isSecureMode + ", user=" + user + ", response=" + resp.toString() + ", serviceName=" + serviceName);
+					LOG.debug("No change in policies. secureMode=" + isSecureMode + ", user=" + user + ", response=" + resp + ", serviceName=" + serviceName);
 				}
 			}
 			ret = null;
@@ -151,7 +155,7 @@ public class RangerAdminRESTClient implements RangerAdminClient {
 			LOG.warn("Received 404 error code with body:[" + exceptionMsg + "], Ignoring");
 		} else {
 			RESTResponse resp = RESTResponse.fromClientResponse(response);
-			LOG.warn("Error getting policies. secureMode=" + isSecureMode + ", user=" + user + ", response=" + resp.toString() + ", serviceName=" + serviceName);
+			LOG.warn("Error getting policies. secureMode=" + isSecureMode + ", user=" + user + ", response=" + resp + ", serviceName=" + serviceName);
 			ret = null;
 		}
 
@@ -189,11 +193,11 @@ public class RangerAdminRESTClient implements RangerAdminClient {
                                                                                 .queryParam(RangerRESTUtils.REST_PARAM_PLUGIN_ID, pluginId);
 			response = webResource.accept(RangerRESTUtils.REST_EXPECTED_MIME_TYPE).type(RangerRESTUtils.REST_EXPECTED_MIME_TYPE).post(ClientResponse.class, restClient.toJson(request));
 		}
-		if(response != null && response.getStatus() != 200) {
+		if(response != null && response.getStatus() != HttpServletResponse.SC_OK) {
 			RESTResponse resp = RESTResponse.fromClientResponse(response);
 			LOG.error("grantAccess() failed: HTTP status=" + response.getStatus() + ", message=" + resp.getMessage() + ", isSecure=" + isSecureMode + (isSecureMode ? (", user=" + user) : ""));
 
-			if(response.getStatus() == 401) {
+			if(response.getStatus()==HttpServletResponse.SC_UNAUTHORIZED) {
 				throw new AccessControlException();
 			}
 
@@ -235,11 +239,11 @@ public class RangerAdminRESTClient implements RangerAdminClient {
 			response = webResource.accept(RangerRESTUtils.REST_EXPECTED_MIME_TYPE).type(RangerRESTUtils.REST_EXPECTED_MIME_TYPE).post(ClientResponse.class, restClient.toJson(request));
 		}
 
-		if(response != null && response.getStatus() != 200) {
+		if(response != null && response.getStatus() != HttpServletResponse.SC_OK) {
 			RESTResponse resp = RESTResponse.fromClientResponse(response);
 			LOG.error("revokeAccess() failed: HTTP status=" + response.getStatus() + ", message=" + resp.getMessage() + ", isSecure=" + isSecureMode + (isSecureMode ? (", user=" + user) : ""));
 
-			if(response.getStatus() == 401) {
+			if(response.getStatus() == HttpServletResponse.SC_UNAUTHORIZED) {
 				throw new AccessControlException();
 			}
 
@@ -314,7 +318,7 @@ public class RangerAdminRESTClient implements RangerAdminClient {
 				RESTResponse resp = RESTResponse.fromClientResponse(response);
 				if (LOG.isDebugEnabled()) {
 					LOG.debug("No change in tags. secureMode=" + isSecureMode + ", user=" + user
-							+ ", response=" + resp.toString() + ", serviceName=" + serviceName
+							+ ", response=" + resp + ", serviceName=" + serviceName
 							+ ", " + "lastKnownVersion=" + lastKnownVersion
 							+ ", " + "lastActivationTimeInMillis=" + lastActivationTimeInMillis);
 				}
@@ -334,7 +338,7 @@ public class RangerAdminRESTClient implements RangerAdminClient {
 			LOG.warn("Received 404 error code with body:[" + exceptionMsg + "], Ignoring");
 		} else {
 			RESTResponse resp = RESTResponse.fromClientResponse(response);
-			LOG.warn("Error getting tags. secureMode=" + isSecureMode + ", user=" + user + ", response=" + resp.toString() + ", serviceName=" + serviceName);
+			LOG.warn("Error getting tags. secureMode=" + isSecureMode + ", user=" + user + ", response=" + resp + ", serviceName=" + serviceName);
 			ret = null;
 		}
 
@@ -375,12 +379,12 @@ public class RangerAdminRESTClient implements RangerAdminClient {
 			response = webResource.accept(RangerRESTUtils.REST_MIME_TYPE_JSON).get(ClientResponse.class);
 		}
 
-		if(response != null && response.getStatus() == 200) {
+		if(response != null && response.getStatus() == HttpServletResponse.SC_OK) {
 			ret = response.getEntity(getGenericType(emptyString));
 		} else {
 			RESTResponse resp = RESTResponse.fromClientResponse(response);
-			LOG.error("Error getting tags. request=" + webResource.toString()
-					+ ", response=" + resp.toString() + ", serviceName=" + serviceName
+			LOG.error("Error getting tags. request=" + webResource
+					+ ", response=" + resp + ", serviceName=" + serviceName
 					+ ", " + "pattern=" + pattern);
 			throw new Exception(resp.getMessage());
 		}
