@@ -37,15 +37,18 @@ public abstract class BaseClient {
 
 
 	private static final String DEFAULT_NAME_RULE = "DEFAULT";
+	private static final String DEFAULT_ERROR_MESSAGE = " You can still save the repository and start creating "
+				+ "policies, but you would not be able to use autocomplete for "
+				+ "resource names. Check ranger_admin.log for more info.";
 
 
 	private String serviceName;
   	private String defaultConfigFile;
 	private Subject loginSubject;
 	private HadoopConfigHolder configHolder;
-	
+
 	protected Map<String,String> connectionProperties;
-	
+
   public BaseClient(String svcName, Map<String,String> connectionProperties) {
     this(svcName, connectionProperties, null);
   }
@@ -57,8 +60,8 @@ public abstract class BaseClient {
 		init();
 		login();
 	}
-	
-	
+
+
 	private void init() {
 		if (connectionProperties == null) {
 			configHolder = HadoopConfigHolder.getInstance(serviceName);
@@ -67,13 +70,10 @@ public abstract class BaseClient {
 			configHolder = HadoopConfigHolder.getInstance(serviceName,connectionProperties, defaultConfigFile);
 		}
 	}
-	
-	
+
+
 	protected void login() {
 		ClassLoader prevCl = Thread.currentThread().getContextClassLoader();
-		String errMsg = " You can still save the repository and start creating "
-				+ "policies, but you would not be able to use autocomplete for "
-				+ "resource names. Check ranger_admin.log for more info.";
 		try {
 			//Thread.currentThread().setContextClassLoader(configHolder.getClassLoader());
 			 String lookupPrincipal = SecureClientLogin.getPrincipal(configHolder.getLookupPrincipal(), java.net.InetAddress.getLocalHost().getCanonicalHostName());
@@ -81,20 +81,14 @@ public abstract class BaseClient {
 			 String nameRules = configHolder.getNameRules();
 			 if(StringUtils.isEmpty(nameRules)){
 				 if(LOG.isDebugEnabled()){
-					 LOG.debug("Name is empty. Setting Name Rule as 'DEFAULT'");
+					 LOG.debug("Name Rule is empty. Setting Name Rule as 'DEFAULT'");
 				 }
 				 nameRules = DEFAULT_NAME_RULE;
 			 }
 			 String userName = configHolder.getUserName();
-			 if(StringUtils.isEmpty(lookupPrincipal) || StringUtils.isEmpty(lookupKeytab)){				
+			 if(StringUtils.isEmpty(lookupPrincipal) || StringUtils.isEmpty(lookupKeytab)){
 				 if (userName == null) {
-					 String msgDesc = "Unable to find login username for hadoop environment, ["
-						+ serviceName + "]";
-					 HadoopException hdpException = new HadoopException(msgDesc);
-					 hdpException.generateResponseDataMap(false, msgDesc + errMsg, msgDesc + errMsg,
-						null, null);
-
-					 throw hdpException;
+					throw createException("Unable to find login username for hadoop environment, [" + serviceName + "]", null);
 				 }
 				 String keyTabFile = configHolder.getKeyTabFile();
 				 if (keyTabFile != null) {
@@ -109,7 +103,21 @@ public abstract class BaseClient {
 				 }
 				 else {
 					 String encryptedPwd = configHolder.getPassword();
-					 String password = PasswordUtils.decryptPassword(encryptedPwd);
+					 String password = null;
+					 if (encryptedPwd != null) {
+					     try {
+					         password = PasswordUtils.decryptPassword(encryptedPwd);
+					     } catch(Exception ex) {
+					         LOG.info("Password decryption failed; trying connection with received password string");
+					         password = null;
+					     } finally {
+					         if (password == null) {
+					             password = encryptedPwd;
+					         }
+					     }
+					 } else {
+					     LOG.info("Password decryption failed: no password was configured");
+					 }
 					 if ( configHolder.isKerberosAuthentication() ) {
 						 LOG.info("Init Login: using username/password");
 						 loginSubject = SecureClientLogin.loginUserWithPassword(userName, password);
@@ -125,29 +133,30 @@ public abstract class BaseClient {
 					 loginSubject = SecureClientLogin.loginUserFromKeytab(lookupPrincipal, lookupKeytab, nameRules);
 				 }else{
 					 LOG.info("Init Login: security not enabled, using username");
-					 loginSubject = SecureClientLogin.login(userName);					
+					 loginSubject = SecureClientLogin.login(userName);
 				 }
 			 }
 		} catch (IOException ioe) {
-			String msgDesc = "Unable to login to Hadoop environment ["
-					+ serviceName + "]";
-
-			HadoopException hdpException = new HadoopException(msgDesc, ioe);
-			hdpException.generateResponseDataMap(false, getMessage(ioe) +  errMsg,
-					msgDesc + errMsg, null, null);
-			throw hdpException;
+			throw createException(ioe);
 		} catch (SecurityException se) {
-			String msgDesc = "Unable to login to Hadoop environment ["
-					+ serviceName + "]";
-			HadoopException hdpException = new HadoopException(msgDesc, se);
-			hdpException.generateResponseDataMap(false, getMessage(se) +  errMsg,
-					msgDesc + errMsg, null, null);
-			throw hdpException;
+			throw createException(se);
 		} finally {
 			Thread.currentThread().setContextClassLoader(prevCl);
 		}
 	}
-	
+
+	private HadoopException createException(Exception exp) {
+		return createException("Unable to login to Hadoop environment [" + serviceName + "]", exp);
+	}
+
+	private HadoopException createException(String msgDesc, Exception exp) {
+		HadoopException hdpException = new HadoopException(msgDesc, exp);
+		final String fullDescription = exp != null ? getMessage(exp) : msgDesc;
+		hdpException.generateResponseDataMap(false, fullDescription + DEFAULT_ERROR_MESSAGE,
+			msgDesc + DEFAULT_ERROR_MESSAGE, null, null);
+		return hdpException;
+	}
+
 	public String getSerivceName() {
 		return serviceName;
 	}
@@ -159,7 +168,7 @@ public abstract class BaseClient {
 	protected HadoopConfigHolder getConfigHolder() {
 		return configHolder;
 	}
-	
+
 	public static void generateResponseDataMap(boolean connectivityStatus,
 			String message, String description, Long objectId,
 			String fieldName, Map<String, Object> responseData) {
@@ -171,12 +180,11 @@ public abstract class BaseClient {
 	}
 
 	public static String getMessage(Throwable excp) {
-		List<String> errList = new ArrayList<String>();
+		List<String> errList = new ArrayList<>();
 		while (excp != null) {
-			if (!errList.contains(excp.getMessage() + ". \n")) {
-				if (excp.getMessage() != null && !(excp.getMessage().equalsIgnoreCase(""))) {
-					errList.add(excp.getMessage() + ". \n");
-				}
+			String message = excp.getMessage();
+			if (StringUtils.isNotEmpty(message) && !errList.contains(message + ". \n")) {
+				errList.add(message + ". \n");
 			}
 			excp = excp.getCause();
 		}
