@@ -33,6 +33,7 @@ import org.apache.commons.collections.CollectionUtils;
 import org.apache.commons.lang.StringUtils;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.ranger.plugin.errors.ValidationErrorCode;
 import org.apache.ranger.plugin.model.RangerPolicy;
 import org.apache.ranger.plugin.model.RangerPolicy.RangerPolicyResource;
 import org.apache.ranger.plugin.model.RangerService;
@@ -96,7 +97,7 @@ public abstract class RangerValidator {
 		return false;
 	}
 
-	String serializeFailures(List<ValidationFailureDetails> failures) {
+	public static String serializeFailures(List<ValidationFailureDetails> failures) {
 		if(LOG.isDebugEnabled()) {
 			LOG.debug("==> RangerValidator.getFailureMessage()");
 		}
@@ -588,6 +589,33 @@ public abstract class RangerValidator {
 		return valid;
 	}
 
+	boolean isValidResourceName(final String value, final String valueContext, final List<ValidationFailureDetails> failures) {
+		boolean ret = true;
+
+		if (value != null && !StringUtils.isEmpty(value)) {
+			int sz = value.length();
+
+			for(int i = 0; i < sz; ++i) {
+				char c = value.charAt(i);
+				if (!(Character.isLowerCase(c) || c == '-' || c == '_')) { // Allow only lowercase, hyphen or underscore characters
+					ret = false;
+					break;
+				}
+			}
+		} else {
+			ret = false;
+		}
+		if (!ret) {
+			ValidationErrorCode errorCode = ValidationErrorCode.SERVICE_DEF_VALIDATION_ERR_NOT_LOWERCASE_NAME;
+			failures.add(new ValidationFailureDetailsBuilder()
+					.errorCode(errorCode.getErrorCode())
+					.field(value)
+					.becauseOf(errorCode.getMessage(valueContext, value))
+					.build());
+		}
+		return ret;
+	}
+
 	boolean isUnique(final String value, final Set<String> alreadySeen, final String valueName, final String collectionName, final List<ValidationFailureDetails> failures) {
 		return isUnique(value, null, alreadySeen, valueName, collectionName, failures);
 	}
