@@ -392,6 +392,13 @@ public class TestRangerServiceDefValidator {
 			{ 3L,      30,       "  " } // Name is all whitespace
 	};
 
+	Object[][] mixedCaseResources = new Object[][] {
+			//  { id,   level,      name }
+			{ 4L,     -10, "DBase" }, // -ve value for level is ok
+			{ 5L,      10,    "TABLE" }, // id is duplicate
+			{ 6L,     -10, "Column" } // (in different case) but name and level are duplicate
+	};
+
 	@Test
 	public final void test_isValidResources() {
 		// null/empty resources are an error
@@ -410,6 +417,12 @@ public class TestRangerServiceDefValidator {
 		_utils.checkFailureForMissingValue(_failures, "resource itemId");
 		_utils.checkFailureForSemanticError(_failures, "resource itemId", "1"); // id 1 is duplicate
 		_utils.checkFailureForSemanticError(_failures, "resource name", "DataBase");
+
+		resources.clear(); resources.addAll(_utils.createResourceDefsWithIds(mixedCaseResources));
+		_failures.clear(); assertFalse(_validator.isValidResources(_serviceDef, _failures));
+		_utils.checkFailure(_failures, null, null, null, "DBase",null);
+		_utils.checkFailure(_failures, null, null, null, "TABLE",null);
+		_utils.checkFailure(_failures, null, null, null, "Column",null);
 	}
 	
 	@Test
