@@ -27,6 +27,7 @@ import com.google.gson.JsonElement;
 import com.google.gson.JsonParseException;
 import com.google.gson.reflect.TypeToken;
 
+import org.apache.commons.collections.CollectionUtils;
 import org.apache.commons.lang.StringUtils;
 import org.apache.ranger.audit.provider.AuditHandler;
 import org.apache.ranger.audit.provider.AuditProviderFactory;
@@ -35,7 +36,11 @@ import org.apache.ranger.plugin.audit.RangerDefaultAuditHandler;
 import org.apache.ranger.plugin.contextenricher.RangerTagForEval;
 import org.apache.ranger.plugin.model.RangerPolicy;
 import org.apache.ranger.plugin.model.RangerServiceDef;
+import org.apache.ranger.plugin.model.RangerValiditySchedule;
+import org.apache.ranger.plugin.model.validation.RangerValidityScheduleValidator;
+import org.apache.ranger.plugin.model.validation.ValidationFailureDetails;
 import org.apache.ranger.plugin.policyengine.TestPolicyEngine.PolicyEngineTestCase.TestData;
+import org.apache.ranger.plugin.policyevaluator.RangerValidityScheduleEvaluator;
 import org.apache.ranger.plugin.util.RangerAccessRequestUtil;
 import org.apache.ranger.plugin.util.RangerRequestedResources;
 import org.apache.ranger.plugin.util.ServicePolicies;
@@ -50,10 +55,13 @@ import java.io.InputStream;
 import java.io.InputStreamReader;
 import java.io.OutputStreamWriter;
 import java.lang.reflect.Type;
+import java.util.ArrayList;
+import java.util.Date;
 import java.util.List;
 import java.util.Map;
 import java.util.Properties;
 import java.util.Set;
+import java.util.TimeZone;
 
 import static org.junit.Assert.*;
 
@@ -62,7 +70,7 @@ public class TestPolicyEngine {
 
 	@BeforeClass
 	public static void setUpBeforeClass() throws Exception {
-		gsonBuilder = new GsonBuilder().setDateFormat("yyyyMMdd-HH:mm:ss.SSS-Z")
+		gsonBuilder = new GsonBuilder().setDateFormat("yyyyMMdd-HH:mm:ss.SSSZ")
 				.setPrettyPrinting()
 				.registerTypeAdapter(RangerAccessRequest.class, new RangerAccessRequestDeserializer())
 				.registerTypeAdapter(RangerAccessResource.class, new RangerResourceDeserializer())
@@ -99,9 +107,10 @@ public class TestPolicyEngine {
 			auditProperties.setProperty("xasecure.audit.db.batch.size", "100");
 		}
 
-		AuditProviderFactory.getInstance().init(auditProperties, "hdfs"); // second parameter does not matter for v2
+		AuditProviderFactory factory = new AuditProviderFactory();
+		factory.init(auditProperties, "hdfs"); // second parameter does not matter for v2
 
-		AuditHandler provider = AuditProviderFactory.getAuditProvider();
+		AuditHandler provider = factory.getAuditProvider();
 
 		System.out.println("provider=" + provider.toString());
 
@@ -301,6 +310,24 @@ public class TestPolicyEngine {
 
 		runTestsFromResourceFiles(resourceFiles);
 	}
+	@Test
+	public void testPolicyEngine_temporary() {
+		String[] resourceFiles = {"/policyengine/test_policyengine_temporary.json"};
+
+		TimeZone defaultTZ = TimeZone.getDefault();
+		TimeZone.setDefault(TimeZone.getTimeZone("PST"));
+
+		runTestsFromResourceFiles(resourceFiles);
+
+		TimeZone.setDefault(defaultTZ);
+	}
+
+	@Test
+	public void testPolicyEngine_atlas() {
+		String[] resourceFiles = { "/policyengine/test_policyengine_atlas.json" };
+
+		runTestsFromResourceFiles(resourceFiles);
+	}
 
 	private void runTestsFromResourceFiles(String[] resourceNames) {
 		for(String resourceName : resourceNames) {
@@ -340,6 +367,7 @@ public class TestPolicyEngine {
 		RangerPolicyEngineOptions policyEngineOptions = new RangerPolicyEngineOptions();
 
 		policyEngineOptions.disableTagPolicyEvaluation = false;
+		policyEngineOptions.disableAccessEvaluationWithPolicyACLSummary = false;
 
 		boolean useForwardedIPAddress = RangerConfiguration.getInstance().getBoolean("ranger.plugin.hive.use.x-forwarded-for.ipaddress", false);
 		String trustedProxyAddressString = RangerConfiguration.getInstance().get("ranger.plugin.hive.trusted.proxy.ipaddresses");
@@ -350,8 +378,16 @@ public class TestPolicyEngine {
 			}
 		}
 		RangerPolicyEngine policyEngine = new RangerPolicyEngineImpl(testName, servicePolicies, policyEngineOptions);
+
 		policyEngine.setUseForwardedIPAddress(useForwardedIPAddress);
 		policyEngine.setTrustedProxyAddresses(trustedProxyAddresses);
+
+		policyEngineOptions.disableAccessEvaluationWithPolicyACLSummary = true;
+		RangerPolicyEngine policyEngineForResourceAccessInfo = new RangerPolicyEngineImpl(testName, servicePolicies, policyEngineOptions);
+
+		policyEngineForResourceAccessInfo.setUseForwardedIPAddress(useForwardedIPAddress);
+		policyEngineForResourceAccessInfo.setTrustedProxyAddresses(trustedProxyAddresses);
+
 		long requestCount = 0L;
 
 		RangerAccessRequest request = null;
@@ -463,8 +499,9 @@ public class TestPolicyEngine {
 			}
 
 			if(test.resourceAccessInfo != null) {
+
 				RangerResourceAccessInfo expected = new RangerResourceAccessInfo(test.resourceAccessInfo);
-				RangerResourceAccessInfo result   = policyEngine.getResourceAccessInfo(test.request);
+				RangerResourceAccessInfo result   = policyEngineForResourceAccessInfo.getResourceAccessInfo(test.request);
 
 				assertNotNull("result was null! - " + test.name, result);
 				assertEquals("allowedUsers mismatched! - " + test.name, expected.getAllowedUsers(), result.getAllowedUsers());
@@ -498,14 +535,102 @@ public class TestPolicyEngine {
 			public List<RangerPolicy> tagPolicies;
 		}
 	}
-	
-	static class RangerAccessRequestDeserializer implements JsonDeserializer<RangerAccessRequest> {
+
+    static class ValiditySchedulerTestResult {
+        boolean isValid;
+        int validationFailureCount;
+        boolean isApplicable;
+    }
+
+    static class ValiditySchedulerTestCase {
+        String name;
+        List<RangerValiditySchedule> validitySchedules;
+        Date accessTime;
+        ValiditySchedulerTestResult result;
+    }
+
+    @Test
+    public void testValiditySchedulerInvalid() {
+        String resourceName = "/policyengine/validityscheduler/test-validity-schedules-invalid.json";
+
+        runValiditySchedulerTests(resourceName);
+    }
+
+    @Test
+    public void testValiditySchedulerValid() {
+        String resourceName = "/policyengine/validityscheduler/test-validity-schedules-valid.json";
+
+        runValiditySchedulerTests(resourceName);
+    }
+
+    @Test
+    public void testValiditySchedulerApplicable() {
+        String resourceName = "/policyengine/validityscheduler/test-validity-schedules-valid-and-applicable.json";
+
+        runValiditySchedulerTests(resourceName);
+    }
+
+    private void runValiditySchedulerTests(String resourceName) {
+        TimeZone defaultTZ = TimeZone.getDefault();
+        TimeZone.setDefault(TimeZone.getTimeZone("PST"));
+
+        List<ValiditySchedulerTestCase> testCases = null;
+
+        InputStream inStream = this.getClass().getResourceAsStream(resourceName);
+        InputStreamReader reader   = new InputStreamReader(inStream);
+        try {
+            Type listType = new TypeToken<List<ValiditySchedulerTestCase>>() {}.getType();
+            testCases = gsonBuilder.fromJson(reader, listType);
+        } catch (Exception e) {
+            assertFalse("Exception in reading validity-scheduler test cases.", true);
+        }
+
+        assertNotNull("TestCases are null!", testCases);
+
+
+        if (CollectionUtils.isNotEmpty(testCases)) {
+            for (ValiditySchedulerTestCase testCase : testCases) {
+                boolean isValid = true;
+                List<ValidationFailureDetails> validationFailures = new ArrayList<>();
+                boolean isApplicable = false;
+
+                List<RangerValiditySchedule> validatedSchedules = new ArrayList<>();
+
+                for (RangerValiditySchedule validitySchedule : testCase.validitySchedules) {
+                    RangerValidityScheduleValidator validator = new RangerValidityScheduleValidator(validitySchedule);
+                    RangerValiditySchedule validatedSchedule = validator.validate(validationFailures);
+                    isValid = isValid && validatedSchedule != null;
+                    if (isValid) {
+                        validatedSchedules.add(validatedSchedule);
+                    }
+                }
+                if (isValid) {
+                    for (RangerValiditySchedule validSchedule : validatedSchedules) {
+                        isApplicable = new RangerValidityScheduleEvaluator(validSchedule).isApplicable(testCase.accessTime.getTime());
+                        if (isApplicable) {
+                            break;
+                        }
+                    }
+                }
+
+                assertTrue(testCase.name, isValid == testCase.result.isValid);
+                assertTrue(testCase.name, isApplicable == testCase.result.isApplicable);
+                assertTrue(testCase.name + ", [" + validationFailures +"]", validationFailures.size() == testCase.result.validationFailureCount);
+            }
+        }
+        TimeZone.setDefault(defaultTZ);
+    }
+
+    static class RangerAccessRequestDeserializer implements JsonDeserializer<RangerAccessRequest> {
 		@Override
 		public RangerAccessRequest deserialize(JsonElement jsonObj, Type type,
 				JsonDeserializationContext context) throws JsonParseException {
 			RangerAccessRequestImpl ret = gsonBuilder.fromJson(jsonObj, RangerAccessRequestImpl.class);
 
 			ret.setAccessType(ret.getAccessType()); // to force computation of isAccessTypeAny and isAccessTypeDelegatedAdmin
+			if (ret.getAccessTime() == null) {
+				ret.setAccessTime(new Date());
+			}
 
 			return ret;
 		}
