@@ -40,14 +40,6 @@ public class buildks {
 						buildksOBJ.createCredential(args);
 					}else if(command.equalsIgnoreCase("list")){
 						buildksOBJ.listCredential(args);
-					}else if(command.equalsIgnoreCase("get")){
-						String credential=buildksOBJ.getCredential(args);
-						if(credential!=null){
-							System.out.println(credential);
-							System.exit(0);
-						}else{
-							System.exit(1);
-						}
 					}else{
 						System.out.println(command +" is not supported in current version of CredentialBuilder API.");
 						System.exit(1);
@@ -94,7 +86,7 @@ public class buildks {
 	    		returnCode=createKeyStore(args);
 	    	}else{
 	    		try{
-	    			System.out.println("Alias already exist!! will try to delete first.");
+	    			System.out.println("The alias " + alias + " already exists!! Will try to delete first.");
 	    			boolean isSilentMode = true;
 	    			String argsDelete[]=new String[4];
 	    			argsDelete[0]="delete";
@@ -407,8 +399,8 @@ public class buildks {
 		if (debugOption != null && "TRUE".equalsIgnoreCase(debugOption)) {
 			StringBuilder tempBuffer=new StringBuilder("");
 			if(args!=null && args.length>0){
-				for(int index=0;index<args.length;index++){
-					tempBuffer.append(args[index]+" ");
+				for (String arg : args) {
+					tempBuffer.append(arg).append(" ");
 				}
 				System.out.println("Command to execute:["+tempBuffer+"]");
 			}
@@ -535,7 +527,7 @@ public class buildks {
 			}
 			if(keystore!=null && !keystore.isEmpty()){
 				File file =new File(keystore);
-				if(file!=null && file.length()==0){
+				if(file!=null && file.exists() && file.length()==0){
 					System.out.println("Provider file '"+keystore+"' is in invalid state or corrupt!! will try to delete first.");
 					file.delete();
 					file=null;
