@@ -19,17 +19,17 @@
 
 package org.apache.ranger.biz;
 
-import java.io.File;
 import java.security.SecureRandom;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Collection;
 import java.util.Collections;
-import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
 
+import javax.servlet.http.HttpServletResponse;
 import org.apache.commons.io.FilenameUtils;
 import org.apache.commons.io.IOCase;
 import org.apache.commons.lang.StringUtils;
@@ -40,11 +40,9 @@ import org.apache.ranger.common.GUIDUtil;
 import org.apache.ranger.common.MessageEnums;
 import org.apache.ranger.common.PropertiesUtil;
 import org.apache.ranger.common.RESTErrorUtil;
-import org.apache.ranger.common.RangerCommonEnums;
 import org.apache.ranger.common.RangerConstants;
 import org.apache.ranger.common.StringUtil;
 import org.apache.ranger.common.UserSessionBase;
-import org.apache.ranger.common.db.BaseDao;
 import org.apache.ranger.db.RangerDaoManager;
 import org.apache.ranger.entity.XXAsset;
 import org.apache.ranger.entity.XXDBBase;
@@ -59,8 +57,6 @@ import org.apache.ranger.entity.XXUser;
 import org.apache.ranger.plugin.model.RangerBaseModelObject;
 import org.apache.ranger.plugin.model.RangerService;
 import org.apache.ranger.plugin.store.EmbeddedServiceDefsUtil;
-import org.apache.ranger.service.AbstractBaseResourceService;
-import org.apache.ranger.view.VXDataObject;
 import org.apache.ranger.view.VXPortalUser;
 import org.apache.ranger.view.VXResource;
 import org.apache.ranger.view.VXResponse;
@@ -92,7 +88,6 @@ public class RangerBizUtil {
 	Set<Class<?>> groupEditableClasses;
 	private Class<?>[] groupEditableClassesList = {};
 
-	Map<String, Integer> classTypeMappings = new HashMap<String, Integer>();
 	private int maxFirstNameLength;
 	int maxDisplayNameLength = 150;
 	public final String EMPTY_CONTENT_DISPLAY_NAME = "...";
@@ -123,39 +118,6 @@ public class RangerBizUtil {
                 random = new SecureRandom();
 	}
 
-	public <T extends XXDBBase> List<? extends XXDBBase> getParentObjects(
-			T object) {
-		List<XXDBBase> parentObjectList = null;
-		// if (checkParentAcess.contains(object.getMyClassType())) {
-		// parentObjectList = new ArrayList<MBase>();
-		// }
-		return parentObjectList;
-	}
-
-	public int getClassType(Class<?> klass) {
-		String className = klass.getName();
-		// See if this mapping is already in the database
-		Integer classType = classTypeMappings.get(className);
-		if (classType == null) {
-			// Instantiate the class and call the getClassType method
-			if (XXDBBase.class.isAssignableFrom(klass)) {
-				try {
-					XXDBBase gjObj = (XXDBBase) klass.newInstance();
-					classType = gjObj.getMyClassType();
-					classTypeMappings.put(className, classType);
-				} catch (Throwable ex) {
-					logger.error("Error instantiating object for class "
-							+ className, ex);
-				}
-			}
-		}
-		if (classType == null) {
-			return RangerCommonEnums.CLASS_TYPE_NONE;
-		} else {
-			return classType;
-		}
-	}
-
 	// Access control methods
 	public void checkSystemAdminAccess() {
 		UserSessionBase currentUserSession = ContextUtil
@@ -167,101 +129,6 @@ public class RangerBizUtil {
 				.create403RESTException("Only System Administrators can add accounts");
 	}
 
-	/**
-	 * @param contentType
-	 * @return
-	 */
-	public int getMimeTypeInt(String contentType) {
-		if ("JPEG".equalsIgnoreCase(contentType)
-				|| "JPG".equalsIgnoreCase(contentType)
-				|| contentType.endsWith("jpg") || contentType.endsWith("jpeg")) {
-			return RangerConstants.MIME_JPEG;
-		}
-		if ("PNG".equalsIgnoreCase(contentType) || contentType.endsWith("png")) {
-			return RangerConstants.MIME_PNG;
-		}
-		return RangerConstants.MIME_UNKNOWN;
-	}
-
-	/**
-	 * @param mimeType
-	 * @return
-	 */
-	public String getMimeType(int mimeType) {
-		switch (mimeType) {
-		case RangerConstants.MIME_JPEG:
-			return "jpg";
-		case RangerConstants.MIME_PNG:
-			return "png";
-		}
-		return "";
-	}
-
-	/**
-	 * @param contentType
-	 * @return
-	 */
-	public String getImageExtension(String contentType) {
-		if (contentType.toLowerCase().endsWith("jpg")
-				|| contentType.toLowerCase().endsWith("jpeg")) {
-			return "jpg";
-		} else if (contentType.toLowerCase().endsWith("png")) {
-			return "png";
-		}
-		return "";
-	}
-
-	/**
-	 * @param file
-	 * @return
-	 */
-	public String getFileNameWithoutExtension(File file) {
-		if (file != null) {
-			String fileName = file.getName();
-			if (fileName.indexOf(".") > 0) {
-				return fileName.substring(0, fileName.indexOf("."));
-			}
-			return fileName;
-
-		}
-		return null;
-	}
-
-	public String getDisplayNameForClassName(XXDBBase obj) {
-		String classTypeDisplayName = RangerConstants
-				.getLabelFor_ClassTypes(obj.getMyClassType());
-		if (classTypeDisplayName == null) {
-			logger.error(
-					"Error get name for class type. obj=" + obj.toString(),
-					new Throwable());
-		}
-		return classTypeDisplayName;
-	}
-
-	public String getDisplayName(XXDBBase obj) {
-		if (obj != null) {
-			return handleGetDisplayName(obj.getMyDisplayValue());
-		} else {
-			return handleGetDisplayName(null);
-		}
-	}
-
-	/**
-	 * @param displayValue
-	 * @return
-	 */
-	private String handleGetDisplayName(String displayValue) {
-		if (displayValue == null || displayValue.trim().isEmpty()) {
-			return EMPTY_CONTENT_DISPLAY_NAME;
-		}
-
-		if (displayValue.length() > maxDisplayNameLength) {
-			displayValue = displayValue.substring(0, maxDisplayNameLength - 3)
-					.concat("...");
-		}
-		return displayValue;
-	}
-
 	/**
 	 * @param userProfile
 	 * @return
@@ -285,92 +152,6 @@ public class RangerBizUtil {
 		return publicName;
 	}
 
-	public void updateCloneReferences(XXDBBase obj) {
-		if (obj == null) {
-			return;
-		}
-	}
-
-	public Long getForUserId(XXDBBase resource) {
-		return null;
-	}
-
-	public XXDBBase getMObject(int objClassType, Long objId) {
-		XXDBBase obj = null;
-
-		if (objId != null) {
-			BaseDao<?> dao = daoManager.getDaoForClassType(objClassType);
-
-			if (dao != null) {
-				obj = (XXDBBase) dao.getById(objId);
-			}
-		}
-
-		return obj;
-	}
-
-	public XXDBBase getMObject(VXDataObject vXDataObject) {
-		if (vXDataObject != null) {
-			return getMObject(vXDataObject.getMyClassType(),
-					vXDataObject.getId());
-		}
-		return null;
-	}
-
-	public VXDataObject getVObject(int objClassType, Long objId) {
-		if (objId == null) {
-			return null;
-		}
-		if (objClassType == RangerConstants.CLASS_TYPE_USER_PROFILE) {
-			return userMgr.mapXXPortalUserVXPortalUser(daoManager
-					.getXXPortalUser().getById(objId));
-		}
-		try {
-			AbstractBaseResourceService<?, ?> myService = AbstractBaseResourceService
-					.getService(objClassType);
-			if (myService != null) {
-				return myService.readResource(objId);
-			}
-		} catch (Throwable t) {
-			logger.error("Error reading resource. objectClassType="
-					+ objClassType + ", objectId=" + objId, t);
-		}
-		return null;
-	}
-
-	public void deleteReferencedObjects(XXDBBase obj) {
-
-		if (obj == null) {
-			return;
-		}
-		if (obj.getMyClassType() == RangerConstants.CLASS_TYPE_NONE) {
-			return;
-		}
-
-	}
-
-	/**
-	 * @param obj
-	 */
-	void deleteObjects(List<XXDBBase> objs) {
-
-	}
-
-	void deleteObject(XXDBBase obj) {
-		AbstractBaseResourceService<?, ?> myService = AbstractBaseResourceService
-				.getService(obj.getMyClassType());
-		if (myService != null) {
-			myService.deleteResource(obj.getId());
-		} else {
-			logger.error("Service not found for obj=" + obj, new Throwable());
-		}
-	}
-
-	public <T extends XXDBBase> Class<? extends XXDBBase> getContextObject(
-			int objectClassType, Long objectId) {
-		return null;
-	}
-
 	public VXStringList mapStringListToVStringList(List<String> stringList) {
 		if (stringList == null) {
 			return null;
@@ -543,6 +324,19 @@ public class RangerBizUtil {
 		return false;
 	}
 
+    public boolean isAuditAdmin() {
+        UserSessionBase currentUserSession = ContextUtil
+                            .getCurrentUserSession();
+            if (currentUserSession == null) {
+                logger.debug("Unable to find session.");
+            return false;
+            }
+            if (currentUserSession.isAuditUserAdmin()) {
+                return true;
+            }
+            return false;
+    }
+
 	/**
 	 * return username of currently logged in user
 	 *
@@ -1421,6 +1215,17 @@ public class RangerBizUtil {
 		}
 		return false;
 	}
+    public boolean isAuditKeyAdmin() {
+        UserSessionBase currentUserSession = ContextUtil.getCurrentUserSession();
+        if (currentUserSession == null) {
+                logger.debug("Unable to find session.");
+                return false;
+        }
+        if (currentUserSession.isAuditKeyAdmin()) {
+                return true;
+        }
+        return false;
+    }
 
 	/**
 	 * @param xxDbBase
@@ -1438,24 +1243,24 @@ public class RangerBizUtil {
 
 		boolean isKeyAdmin = session.isKeyAdmin();
 		boolean isSysAdmin = session.isUserAdmin();
+		boolean isAuditor =  session.isAuditUserAdmin();
+		boolean isAuditorKeyAdmin = session.isAuditKeyAdmin();
 		boolean isUser = false;
 
 		List<String> roleList = session.getUserRoleList();
-		if (roleList.contains(RangerConstants.ROLE_USER)) {
+		if (roleList.contains(RangerConstants.ROLE_USER) ) {
 			isUser = true;
 		}
 
 		if (xxDbBase != null && xxDbBase instanceof XXServiceDef) {
 			XXServiceDef xServiceDef = (XXServiceDef) xxDbBase;
-			String implClass = xServiceDef.getImplclassname();
-			if (implClass == null) {
-				return false;
-			}
-
-			if (isKeyAdmin && EmbeddedServiceDefsUtil.KMS_IMPL_CLASS_NAME.equals(implClass)) {
-				return true;
-			} else if ((isSysAdmin || isUser) && !EmbeddedServiceDefsUtil.KMS_IMPL_CLASS_NAME.equals(implClass)) {
-				return true;
+			final String implClass = xServiceDef.getImplclassname();
+			if (EmbeddedServiceDefsUtil.KMS_IMPL_CLASS_NAME.equals(implClass)) {
+				// KMS case
+				return isKeyAdmin || isAuditorKeyAdmin;
+			} else {
+				// Other cases - implClass can be null!
+				return isSysAdmin || isUser || isAuditor;
 			}
 		}
 
@@ -1463,25 +1268,20 @@ public class RangerBizUtil {
 
 			// TODO: As of now we are allowing SYS_ADMIN to create/update/read/delete all the
 			// services including KMS
-			if (isSysAdmin) {
+			if (isSysAdmin || isAuditor) {
 				return true;
 			}
 
 			XXService xService = (XXService) xxDbBase;
 			XXServiceDef xServiceDef = daoManager.getXXServiceDef().getById(xService.getType());
 			String implClass = xServiceDef.getImplclassname();
-			if (implClass == null) {
-				return false;
+			if (EmbeddedServiceDefsUtil.KMS_IMPL_CLASS_NAME.equals(implClass)) {
+				// KMS case
+				return isKeyAdmin || isAuditorKeyAdmin;
+			} else {
+				// Other cases - implClass can be null!
+				return isUser;
 			}
-
-			if (isKeyAdmin && EmbeddedServiceDefsUtil.KMS_IMPL_CLASS_NAME.equals(implClass)) {
-				return true;
-			} else if (isUser && !EmbeddedServiceDefsUtil.KMS_IMPL_CLASS_NAME.equals(implClass)) {
-				return true;
-			}
-			// else if ((isSysAdmin || isUser) && !implClass.equals(EmbeddedServiceDefsUtil.KMS_IMPL_CLASS_NAME)) {
-			// return true;
-			// }
 		}
 		return false;
 	}
@@ -1520,17 +1320,31 @@ public class RangerBizUtil {
 	}
 
 	public boolean checkUserAccessible(VXUser vXUser) {
-		if(isKeyAdmin() && vXUser.getUserRoleList().contains(RangerConstants.ROLE_SYS_ADMIN)) {
-			throw restErrorUtil.createRESTException("Logged in user is not allowd to create/update user",
+                boolean isAccessible = true;
+                Collection<String> roleList = userMgr.getRolesByLoginId(vXUser
+                                .getName());
+                if (isKeyAdmin()) {
+                        if (vXUser.getUserRoleList().contains(RangerConstants.ROLE_SYS_ADMIN)
+                                        || vXUser.getUserRoleList().contains(RangerConstants.ROLE_ADMIN_AUDITOR)
+                                        || roleList.contains(RangerConstants.ROLE_SYS_ADMIN)
+                                        || roleList.contains(RangerConstants.ROLE_ADMIN_AUDITOR)) {
+                                isAccessible = false;
+                        }
+                }
+                if (isAdmin()) {
+                        if (vXUser.getUserRoleList().contains(RangerConstants.ROLE_KEY_ADMIN)
+                                        || vXUser.getUserRoleList().contains(RangerConstants.ROLE_KEY_ADMIN_AUDITOR)
+                                        || roleList.contains(RangerConstants.ROLE_KEY_ADMIN)
+                                        || roleList.contains(RangerConstants.ROLE_KEY_ADMIN_AUDITOR)) {
+                                isAccessible = false;
+                        }
+                }
+                if (!isAccessible) {
+                        throw restErrorUtil.createRESTException(
+                                        "Logged in user is not allowed to create/update user",
 					MessageEnums.OPER_NO_PERMISSION);
 		}
-
-		if(isAdmin() && vXUser.getUserRoleList().contains(RangerConstants.ROLE_KEY_ADMIN)) {
-			throw restErrorUtil.createRESTException("Logged in user is not allowd to create/update user",
-					MessageEnums.OPER_NO_PERMISSION);
-		}
-
-		return true;
+                return isAccessible;
 	}
 	
 	public boolean isSSOEnabled() {
@@ -1583,4 +1397,24 @@ public class RangerBizUtil {
 		return false;
 	}	
 
+        public void blockAuditorRoleUser() {
+                UserSessionBase session = ContextUtil.getCurrentUserSession();
+                if (session != null) {
+                        if (session.isAuditKeyAdmin() || session.isAuditUserAdmin()) {
+                                VXResponse vXResponse = new VXResponse();
+                                vXResponse.setStatusCode(HttpServletResponse.SC_UNAUTHORIZED);
+                                vXResponse.setMsgDesc("Operation"
+                                                + " denied. LoggedInUser="
+                                                +  session.getXXPortalUser().getId()
+                                                + " ,isn't permitted to perform the action.");
+                                throw restErrorUtil.generateRESTException(vXResponse);
+                        }
+                } else {
+                        VXResponse vXResponse = new VXResponse();
+                        vXResponse.setStatusCode(HttpServletResponse.SC_UNAUTHORIZED);
+                        vXResponse.setMsgDesc("Bad Credentials");
+                        throw restErrorUtil.generateRESTException(vXResponse);
+                }
+        }
+
 }
