@@ -25,6 +25,7 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
+import javax.annotation.Nonnull;
 import javax.persistence.EntityManager;
 import javax.persistence.Query;
 import javax.servlet.http.HttpServletRequest;
@@ -32,6 +33,7 @@ import javax.servlet.http.HttpServletRequest;
 import org.apache.commons.collections.MapUtils;
 import org.apache.commons.lang.ArrayUtils;
 import org.apache.commons.lang.StringUtils;
+import org.apache.commons.lang.Validate;
 import org.apache.log4j.Logger;
 import org.apache.ranger.plugin.util.SearchFilter;
 import org.springframework.stereotype.Component;
@@ -40,10 +42,8 @@ import org.springframework.stereotype.Component;
 public class RangerSearchUtil extends SearchUtil {
 	final static Logger logger = Logger.getLogger(RangerSearchUtil.class);
 	
-	public SearchFilter getSearchFilter(HttpServletRequest request, List<SortField> sortFields) {
-		if (request == null) {
-			return null;
-		}
+	public SearchFilter getSearchFilter(@Nonnull HttpServletRequest request, List<SortField> sortFields) {
+		Validate.notNull(request, "request");
 		SearchFilter ret = new SearchFilter();
 
 		if (MapUtils.isEmpty(request.getParameterMap())) {
@@ -113,9 +113,7 @@ public class RangerSearchUtil extends SearchUtil {
 
 
 	public SearchFilter getSearchFilterFromLegacyRequest(HttpServletRequest request, List<SortField> sortFields) {
-		if (request == null) {
-			return null;
-		}
+		Validate.notNull(request, "request");
 		SearchFilter ret = new SearchFilter();
 
 		if (MapUtils.isEmpty(request.getParameterMap())) {
@@ -201,12 +199,12 @@ public class RangerSearchUtil extends SearchUtil {
 	public Query createSearchQuery(EntityManager em, String queryStr, String sortClause,
 			SearchFilter searchCriteria, List<SearchField> searchFields,
 			boolean isCountQuery) {
-		return createSearchQuery(em, queryStr, sortClause, searchCriteria, searchFields, -1, false, isCountQuery);
+		return createSearchQuery(em, queryStr, sortClause, searchCriteria, searchFields, false, isCountQuery);
 	}
 	
 	public Query createSearchQuery(EntityManager em, String queryStr, String sortClause,
 			SearchFilter searchCriteria, List<SearchField> searchFields,
-			int objectClassType, boolean hasAttributes, boolean isCountQuery) {
+			boolean hasAttributes, boolean isCountQuery) {
 
 		StringBuilder queryClause = buildWhereClause(searchCriteria, searchFields);
 		super.addOrderByClause(queryClause, sortClause);
