@@ -42,7 +42,7 @@ public class RangerServicePoliciesCache {
 
 	private static final int MAX_WAIT_TIME_FOR_UPDATE = 10;
 
-	private static volatile RangerServicePoliciesCache sInstance = null;
+	public static volatile RangerServicePoliciesCache sInstance = null;
 	private final boolean useServicePoliciesCache;
 	private final int waitTimeInSeconds;
 
@@ -270,7 +270,7 @@ public class RangerServicePoliciesCache {
 					policy.setCreateTime(null);
 					policy.setUpdatedBy(null);
 					policy.setUpdateTime(null);
-					policy.setGuid(null);
+					// policy.setGuid(null); /* this is used by import policy */
 					// policy.setName(null); /* this is used by GUI in policy list page */
 					// policy.setDescription(null); /* this is used by export policy */
 					policy.setResourceSignature(null);
