@@ -690,7 +690,7 @@ public class SearchUtil {
 
 	public Query createSearchQuery(EntityManager em, String queryStr, String sortClause,
 			SearchCriteria searchCriteria, List<SearchField> searchFields,
-			int objectClassType, boolean hasAttributes, boolean isCountQuery) {
+			boolean hasAttributes, boolean isCountQuery) {
 
 		// [1] Build where clause
 		StringBuilder queryClause = buildWhereClause(searchCriteria,
@@ -725,13 +725,6 @@ public class SearchUtil {
 
 		return query;
 	}
-
-	public Query createSearchQuery(EntityManager em, String queryStr, String sortClause,
-			SearchCriteria searchCriteria, List<SearchField> searchFields,
-			boolean isCountQuery) {
-		return createSearchQuery(em, queryStr, sortClause, searchCriteria,
-				searchFields, -1, false, isCountQuery);
-	}
 	
 	public List<Integer> extractIntList(HttpServletRequest request,
 			SearchCriteria searchCriteria, String paramName,
