@@ -25,7 +25,9 @@ import org.apache.log4j.Logger;
 import org.apache.ranger.common.RangerCommonEnums;
 import org.apache.ranger.common.db.BaseDao;
 import org.apache.ranger.entity.XXAsset;
+import org.springframework.stereotype.Service;
 
+@Service
 public class XXAssetDao extends BaseDao<XXAsset> {
 	private static final Logger logger = Logger.getLogger(XXAssetDao.class);
 
