@@ -30,7 +30,9 @@ import javax.persistence.NoResultException;
 import org.apache.log4j.Logger;
 import org.apache.ranger.common.db.BaseDao;
 import org.apache.ranger.entity.XXResource;
+import org.springframework.stereotype.Service;
 
+@Service
 public class XXResourceDao extends BaseDao<XXResource> {
 	private static final Logger logger = Logger.getLogger(XXResourceDao.class);
 
