@@ -25,10 +25,11 @@ import javax.persistence.NoResultException;
 import org.apache.commons.collections.CollectionUtils;
 import org.apache.ranger.common.db.BaseDao;
 import org.apache.ranger.entity.XXServiceVersionInfo;
+import org.springframework.stereotype.Service;
 
 /**
  */
-
+@Service
 public class XXServiceVersionInfoDao extends BaseDao<XXServiceVersionInfo> {
 	/**
 	 * Default Constructor
