@@ -59,31 +59,7 @@ import org.apache.ranger.service.XPermMapService;
 import org.apache.ranger.service.XResourceService;
 import org.apache.ranger.service.XUserPermissionService;
 import org.apache.ranger.service.XUserService;
-import org.apache.ranger.view.VXAuditMap;
-import org.apache.ranger.view.VXAuditMapList;
-import org.apache.ranger.view.VXAuthSession;
-import org.apache.ranger.view.VXAuthSessionList;
-import org.apache.ranger.view.VXGroup;
-import org.apache.ranger.view.VXGroupGroup;
-import org.apache.ranger.view.VXGroupGroupList;
-import org.apache.ranger.view.VXGroupList;
-import org.apache.ranger.view.VXGroupPermission;
-import org.apache.ranger.view.VXGroupPermissionList;
-import org.apache.ranger.view.VXGroupUser;
-import org.apache.ranger.view.VXGroupUserInfo;
-import org.apache.ranger.view.VXGroupUserList;
-import org.apache.ranger.view.VXLong;
-import org.apache.ranger.view.VXModuleDef;
-import org.apache.ranger.view.VXModuleDefList;
-import org.apache.ranger.view.VXPermMap;
-import org.apache.ranger.view.VXPermMapList;
-import org.apache.ranger.view.VXString;
-import org.apache.ranger.view.VXStringList;
-import org.apache.ranger.view.VXUser;
-import org.apache.ranger.view.VXUserGroupInfo;
-import org.apache.ranger.view.VXUserList;
-import org.apache.ranger.view.VXUserPermission;
-import org.apache.ranger.view.VXUserPermissionList;
+import org.apache.ranger.view.*;
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.context.annotation.Scope;
 import org.springframework.security.access.prepost.PreAuthorize;
@@ -305,6 +281,7 @@ public class XUserREST {
 	@Path("/users")
 	@Produces({ "application/xml", "application/json" })
 	public VXUser updateXUser(VXUser vXUser) {
+                bizUtil.checkUserAccessible(vXUser);
 		return xUserMgr.updateXUser(vXUser);
 	}
 	
@@ -567,14 +544,17 @@ public class XUserREST {
 	@Produces({ "application/xml", "application/json" })
 	@PreAuthorize("@rangerPreAuthSecurityHandler.isAPIAccessible(\"" + RangerAPIList.UPDATE_X_PERM_MAP + "\")")
 	public VXPermMap updateXPermMap(VXPermMap vXPermMap) {
-
+		VXPermMap vXPermMapRet = null;
 		if (vXPermMap != null) {
 			if (xResourceService.readResource(vXPermMap.getResourceId()) == null) {
 				throw restErrorUtil.createRESTException("Invalid Input Data - No resource found with Id: " + vXPermMap.getResourceId());
 			}
+			else{
+				vXPermMapRet = xUserMgr.updateXPermMap(vXPermMap);
+			}
 		}
 
-		return xUserMgr.updateXPermMap(vXPermMap);
+			return vXPermMapRet;
 	}
 
 	@DELETE
@@ -651,14 +631,17 @@ public class XUserREST {
 	@Produces({ "application/xml", "application/json" })
 	@PreAuthorize("@rangerPreAuthSecurityHandler.isAPIAccessible(\"" + RangerAPIList.UPDATE_X_AUDIT_MAP + "\")")
 	public VXAuditMap updateXAuditMap(VXAuditMap vXAuditMap) {
-
+		VXAuditMap vXAuditMapRet = null;
 		if (vXAuditMap != null) {
 			if (xResourceService.readResource(vXAuditMap.getResourceId()) == null) {
 				throw restErrorUtil.createRESTException("Invalid Input Data - No resource found with Id: " + vXAuditMap.getResourceId(), MessageEnums.INVALID_INPUT_DATA);
 			}
+			else{
+				vXAuditMapRet = xUserMgr.updateXAuditMap(vXAuditMap);
+			}
 		}
 
-		return xUserMgr.updateXAuditMap(vXAuditMap);
+		return vXAuditMapRet;
 	}
 
 	@DELETE
@@ -814,6 +797,7 @@ public class XUserREST {
 	@PreAuthorize("@rangerPreAuthSecurityHandler.isAPIAccessible(\"" + RangerAPIList.CREATE_X_MODULE_DEF_PERMISSION + "\")")
 	public VXModuleDef createXModuleDefPermission(VXModuleDef vXModuleDef) {
 		xUserMgr.checkAdminAccess();
+                bizUtil.blockAuditorRoleUser();
 		return xUserMgr.createXModuleDefPermission(vXModuleDef);
 	}
 
@@ -831,6 +815,7 @@ public class XUserREST {
 	@PreAuthorize("@rangerPreAuthSecurityHandler.isAPIAccessible(\"" + RangerAPIList.UPDATE_X_MODULE_DEF_PERMISSION + "\")")
 	public VXModuleDef updateXModuleDefPermission(VXModuleDef vXModuleDef) {
 		xUserMgr.checkAdminAccess();
+                bizUtil.blockAuditorRoleUser();
 		return xUserMgr.updateXModuleDefPermission(vXModuleDef);
 	}
 
@@ -841,6 +826,7 @@ public class XUserREST {
 			@Context HttpServletRequest request) {
 		boolean force = true;
 		xUserMgr.checkAdminAccess();
+                bizUtil.blockAuditorRoleUser();
 		xUserMgr.deleteXModuleDefPermission(id, force);
 	}
 
@@ -883,6 +869,7 @@ public class XUserREST {
 	public VXUserPermission createXUserPermission(
 			VXUserPermission vXUserPermission) {
 		xUserMgr.checkAdminAccess();
+                bizUtil.blockAuditorRoleUser();
 		return xUserMgr.createXUserPermission(vXUserPermission);
 	}
 
@@ -901,6 +888,7 @@ public class XUserREST {
 	public VXUserPermission updateXUserPermission(
 			VXUserPermission vXUserPermission) {
 		xUserMgr.checkAdminAccess();
+                bizUtil.blockAuditorRoleUser();
 		return xUserMgr.updateXUserPermission(vXUserPermission);
 	}
 
@@ -948,6 +936,7 @@ public class XUserREST {
 	public VXGroupPermission createXGroupPermission(
 			VXGroupPermission vXGroupPermission) {
 		xUserMgr.checkAdminAccess();
+                bizUtil.blockAuditorRoleUser();
 		return xUserMgr.createXGroupPermission(vXGroupPermission);
 	}
 
@@ -966,6 +955,7 @@ public class XUserREST {
 	public VXGroupPermission updateXGroupPermission(
 			VXGroupPermission vXGroupPermission) {
 		xUserMgr.checkAdminAccess();
+                bizUtil.blockAuditorRoleUser();
 		return xUserMgr.updateXGroupPermission(vXGroupPermission);
 	}
 
@@ -976,6 +966,7 @@ public class XUserREST {
 			@Context HttpServletRequest request) {
 		boolean force = true;
 		xUserMgr.checkAdminAccess();
+                bizUtil.blockAuditorRoleUser();
 		xUserMgr.deleteXGroupPermission(id, force);
 	}
 
@@ -1155,4 +1146,13 @@ public class XUserREST {
                         xUserMgr.deleteXGroup(groupId, forceDelete);
                 }
         }
-}
\ No newline at end of file
+
+	@POST
+	@Path("/ugsync/auditinfo")
+	@Produces({ "application/xml", "application/json" })
+	@PreAuthorize("hasRole('ROLE_SYS_ADMIN')")
+	public VXUgsyncAuditInfo postUserGroupAuditInfo(VXUgsyncAuditInfo vxUgsyncAuditInfo) {
+
+		return xUserMgr.postUserGroupAuditInfo(vxUgsyncAuditInfo);
+	}
+}
