@@ -215,7 +215,29 @@ public class RangerKRBAuthenticationFilter extends RangerKrbFilter {
 				RangerAuthenticationProvider authenticationProvider = new RangerAuthenticationProvider();
 				Authentication authentication = authenticationProvider.authenticate(finalAuthentication);
 				authentication = getGrantedAuthority(authentication);
-				SecurityContextHolder.getContext().setAuthentication(authentication);	
+				if(authentication != null && authentication.isAuthenticated()) {
+					if (request.getParameterMap().containsKey("doAs")) {
+						if(!response.isCommitted()) {
+							if(LOG.isDebugEnabled()) {
+								LOG.debug("Request contains unsupported parameter, doAs.");
+							}
+							request.setAttribute("spnegoenabled", false);
+							response.sendError(HttpServletResponse.SC_FORBIDDEN, "Missing authentication token.");
+						}
+					}
+					if(request.getParameterMap().containsKey("user.name")) {
+						if(!response.isCommitted()) {
+							if(LOG.isDebugEnabled()) {
+								LOG.debug("Request contains an unsupported parameter user.name");
+							}
+							request.setAttribute("spnegoenabled", false);
+							response.sendError(HttpServletResponse.SC_FORBIDDEN, "Missing authentication token.");
+						} else {
+							LOG.info("Response seems to be already committed for user.name.");
+						}
+					}
+				}
+				SecurityContextHolder.getContext().setAuthentication(authentication);
 				request.setAttribute("spnegoEnabled", true);
 				LOG.info("Logged into Ranger as = "+userName);
 				filterChain.doFilter(request, response);
@@ -236,9 +258,9 @@ public class RangerKRBAuthenticationFilter extends RangerKrbFilter {
 			FilterChain filterChain) throws IOException, ServletException {
 		String authtype = PropertiesUtil.getProperty(RANGER_AUTH_TYPE);
 		HttpServletRequest httpRequest = (HttpServletRequest)request;
-		if(isSpnegoEnable(authtype)){
+		Authentication existingAuth = SecurityContextHolder.getContext().getAuthentication();
+		if(isSpnegoEnable(authtype) && (existingAuth == null || !existingAuth.isAuthenticated())){
 			KerberosName.setRules(PropertiesUtil.getProperty(NAME_RULES, "DEFAULT"));
-			Authentication existingAuth = SecurityContextHolder.getContext().getAuthentication();
 			String userName = null;
 			Cookie[] cookie = httpRequest.getCookies();
 			if(cookie != null){
@@ -261,8 +283,8 @@ public class RangerKRBAuthenticationFilter extends RangerKrbFilter {
 								userName = cname.substring(ustr+2, andStr);
 							}
 						}
-					}			
-				}	
+					}
+				}
 			}
 			if((existingAuth == null || !existingAuth.isAuthenticated()) && (!StringUtils.isEmpty(userName))){
 				//--------------------------- To Create Ranger Session --------------------------------------			
