@@ -518,7 +518,7 @@ public class RangerKrbFilter implements Filter {
 	            Collection<String> headerNames = httpResponse.getHeaderNames();
 	            for(String headerName : headerNames){
 	                String value = httpResponse.getHeader(headerName);
-	                if(headerName.equalsIgnoreCase("Set-Cookie") && value.startsWith("RANGERADMINSESSIONID")){
+	                if("Set-Cookie".equalsIgnoreCase(headerName) && value.startsWith("RANGERADMINSESSIONID")){
 	                    chk = false;
 	                    break;
 	                }
