@@ -27,20 +27,21 @@ import java.util.Map;
 import java.util.Map.Entry;
 
 import org.apache.commons.lang.StringUtils;
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import org.apache.ranger.biz.ServiceDBStore;
 import org.apache.ranger.common.AppConstants;
 import org.apache.ranger.common.JSONUtil;
-import org.apache.ranger.plugin.util.PasswordUtils;
 import org.apache.ranger.common.PropertiesUtil;
 import org.apache.ranger.common.view.VTrxLogAttr;
 import org.apache.ranger.db.XXServiceVersionInfoDao;
 import org.apache.ranger.entity.XXService;
-import org.apache.ranger.entity.XXServiceBase;
 import org.apache.ranger.entity.XXServiceConfigMap;
 import org.apache.ranger.entity.XXServiceDef;
 import org.apache.ranger.entity.XXServiceVersionInfo;
 import org.apache.ranger.entity.XXTrxLog;
 import org.apache.ranger.plugin.model.RangerService;
+import org.apache.ranger.plugin.util.PasswordUtils;
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.context.annotation.Scope;
 import org.springframework.stereotype.Service;
@@ -48,7 +49,7 @@ import org.springframework.stereotype.Service;
 @Service
 @Scope("singleton")
 public class RangerServiceService extends RangerServiceServiceBase<XXService, RangerService> {
-
+	private static final Log LOG = LogFactory.getLog(RangerServiceService.class.getName());
 	@Autowired
 	JSONUtil jsonUtil;
 
@@ -157,7 +158,7 @@ public class RangerServiceService extends RangerServiceServiceBase<XXService, Ra
 			}
 			Field[] superClassFields = vObj.getClass().getSuperclass().getDeclaredFields();
 			for(Field field : superClassFields) {
-				if(field.getName().equalsIgnoreCase("isEnabled")) {
+				if("isEnabled".equalsIgnoreCase(field.getName())) {
 					XXTrxLog xTrx = processFieldToCreateTrxLog(field, objectName, nameField, vObj, mObj, action);
 					if(xTrx != null) {
 						trxLogList.add(xTrx);
@@ -166,9 +167,9 @@ public class RangerServiceService extends RangerServiceServiceBase<XXService, Ra
 				}
 			}
 		} catch (IllegalAccessException e) {
-			e.printStackTrace();
+			LOG.error("Transaction log failure.", e);
 		} catch (NoSuchFieldException e) {
-			e.printStackTrace();
+			LOG.error("Transaction log failure.", e);
 		}
 		return trxLogList;
 	}
@@ -243,7 +244,7 @@ public class RangerServiceService extends RangerServiceServiceBase<XXService, Ra
 							}
 						} else if (!entry.getValue().equalsIgnoreCase(
 								xConfig.get(key))) {
-							if (key.equalsIgnoreCase("password")
+							if ("password".equalsIgnoreCase(key)
 									&& entry.getValue().equalsIgnoreCase(
 											hiddenPasswordString)) {
 								continue;
@@ -275,7 +276,7 @@ public class RangerServiceService extends RangerServiceServiceBase<XXService, Ra
 				xTrxLog.setNewValue(value);
 			}
 		} catch (IllegalArgumentException | IllegalAccessException e) {
-			e.printStackTrace();
+			LOG.error("Process field to create trx log failure." , e);
 		}
 
 		xTrxLog.setAction(actionString);
@@ -295,7 +296,7 @@ public class RangerServiceService extends RangerServiceServiceBase<XXService, Ra
 		Map<String, String> configs = service.getConfigs();
 		
 		String pwd = configs.get(ServiceDBStore.CONFIG_KEY_PASSWORD);
-		if(!stringUtil.isEmpty(pwd) && pwd.equalsIgnoreCase(ServiceDBStore.HIDDEN_PASSWORD_STR)) {
+		if(!stringUtil.isEmpty(pwd) && ServiceDBStore.HIDDEN_PASSWORD_STR.equalsIgnoreCase(pwd)) {
 			XXServiceConfigMap pwdConfig = daoMgr.getXXServiceConfigMap().findByServiceAndConfigKey(service.getId(),
 					ServiceDBStore.CONFIG_KEY_PASSWORD);
                         if (pwdConfig != null) {
@@ -306,10 +307,10 @@ public class RangerServiceService extends RangerServiceServiceBase<XXService, Ra
                                         crypt_algo_array = encryptedPwd.split(",");
                                 }
                                 if (crypt_algo_array != null && crypt_algo_array.length > 1) {
-                                        String cryptAlgo = null;
-                                        String encryptKey = null;
-                                        String salt = null;
-                                        int iterationCount = 0;
+					 String cryptAlgo = null;
+					 String encryptKey = null;
+					 String salt = null;
+					 int iterationCount = 0;
                                         cryptAlgo = crypt_algo_array[0];
                                         encryptKey = crypt_algo_array[1];
                                         salt = crypt_algo_array[2];
