@@ -241,8 +241,29 @@ define(function(require) {
                 download                        : 'Download',
                 lastUpdate                      : 'Last Update',
 		  		modules		                	: 'Modules',
-                                clusterName                     : 'Cluster Name',
-                                policyLabels					: 'Policy Labels'
+                clusterName                     : 'Cluster Name',
+                policyLabels					: 'Policy Labels',
+                activeStatus                    : 'Active Status',
+                selectTagService                : 'Tag Service',
+                syncSource                      : 'Sync Source',
+                unixBackend                     : 'Unix',
+                fileName                        : 'File Name',
+                syncTime                        : 'Sync time',
+                lastModified                    : 'Last modified time',
+                ldapUrl                         : 'Ldap url',
+                isIncrementalSync               : 'Incremental sync',
+                groupHierarchyLevel             : 'Group hierarchy level',
+                minUserId                       : "Minimum user id",
+                minGroupId                      : "Minimum group id",
+                userSearchFilter                : 'User search filter',
+                groupSearchFilter               : 'Group search filter',
+                startDate                       : 'Start Date',
+                endDate                         : 'End Date',
+                                addValidityPeriod				: 'Add Validity Period',
+                                editValidityPeriod				: 'Edit Validity Period',
+                totalUsersSynced                : 'Total number of users synced',
+                totalGroupsSynced               : 'Total number of groups synced',
+
 			},
 			btn : {
 				add							: 'Add',
@@ -320,37 +341,30 @@ define(function(require) {
                 collection                  :'Solr collection.',
                 database                    :'Hive database.',
                 entity                      :'Atlas all-entity.',
-                operation                   :'Atlas all-operation.',
                 path                        :'Name of policy resource.',
                 queue                       :'Yarn queue.',
-                taxonomy                    :'Atlas all-taxonomy.',
-                term                        :'Policy for all-term.',
                 topic                       :'Kafka topic.',
                 type                        :'Policy for all type.',
                 udf                         :'Hive udf.',
                 pluginStatus                :'Plugin Status',
                 clusterName                 :'Name of ambari cluster',
                 url        					:'Hive url.',
-                enabled                     :'enabled',
-                disabled                    :'disabled',
-                Url                         :'Url',
-                recursive                   :'recursive',
-                nonRecursive                :'non-recursive',
-                dataBase                    :'DataBase',
-                exclude                     :'exclude',
-                include                     :'include',
-                yes                         :'Yes',
-                no                          :'No',
-                conditions                  :'Conditions',
-                exAllowCondition            :'Exclude from Allow Conditions',
-                denyCondition               :'Deny Conditions',
-                exDenyCondition             :'Exclude from Deny Conditions',
-                maskingOption               :'Masking Option',
-                masking                     :'Masking',
-                custom                      :'CUSTOM',
-                mask                        :'Mask',
                 rowFilter                   : 'Row Filter',
-                policyLabelsinfo			: 'Label of policy'
+                policyLabelsinfo			: 'Label of policy',
+                serviceDetails              :'Service Details',
+                configProperties            : 'Config Properties',
+                userSync                    :'User Sync',
+                syncSourceInfo              :'Sync Source',
+                syncDetails                  :'Sync Details',
+                typeCategory                :'Atlas type category.',
+                entityType                  :'Atlas entity type.',
+                entityClassification        :'Atlas entity classification.',
+                atlasService                :'Atlas services.',
+                connector                   :'Connectivity By Sqoop.',
+                link                        :'Linker Name.',
+                job                         :'Sqoop Job Name.',
+                project                     :'Kylin Project Level.',
+                nifiResource                :'NiFi Resource Identifier.'
                         },
 			msg : {
 				deletePolicyValidationMsg : 'Policy does not have any settings for the specific resource. Policy will be deleted. Press [Ok] to continue. Press [Cancel] to edit the policy.',
@@ -421,8 +435,10 @@ define(function(require) {
                 addUserOrGroupForDelegateAdmin      : 'Please select user/group for the selected permission(s)',
                 policyLabelsinfo		: 'Enter label of policy',
                 noUserFoundText			: 'No user associate with this group.',
-                showInitialHundredUser  : 'Initially search filter is applied for first hundred users. To get more users click on '
- 
+                showInitialHundredUser  : 'Initially search filter is applied for first hundred users. To get more users click on ',
+                searchForUserSync       :"Search for your user sync audits...",
+                policyExpired           :'Policy Expired'
+
 			},
 			plcHldr : {
 				search 						:'Search',
@@ -450,9 +466,11 @@ define(function(require) {
 				groupNameValidationMsg :'1. Group name should be start with alphabet / numeric / underscore / non-us characters.<br> 2. Allowed special character ,._\-+/@= and space. <br>3. Name length should be greater than one.',
                 firstNameValidationMsg :'1. First name should be start with alphabet / numeric / underscore / non-us characters.<br> 2. Allowed special character ._-@ and space. <br>3. Name length should be greater than one.',
                 lastNameValidationMsg  :'1. Last name should be start with alphabet / numeric / underscore / non-us characters.<br> 2. Allowed special character ._-@ and space. <br>3. Name length should be greater than one.',
+                setTimeZoneErrorMsg    :'Please select Start/End date for Time zone',
+                jsValidationMsg        :'1. JavaScript Condition Examples :\ncountry_code == \'USA\', time_range >= 900 && time_range <= 1800 etc.\n2. Dragging bottom-right corner of javascript condition editor(Textarea) can resizable',
 			},
 			serverMsg : {
-				
+
 				// UserMgr
 				userMgrPassword        : 'The password you\'ve provided is incorrect. Please try again with correct password',
 				userMgrInvalidUser     : 'Invalid user provided',
