@@ -33,6 +33,7 @@ define(function(require){
 	var VXAuditMapList	= require('collections/VXAuditMapList');
 	var VXUserList		= require('collections/VXUserList');
 	var PermissionList 	= require('views/policies/PermissionList');
+  var vPolicyTimeList 	= require('views/policies/PolicyTimeList');
 	var RangerPolicyResource		= require('models/RangerPolicyResource');
 	var BackboneFormDataType	= require('models/BackboneFormDataType');
 
@@ -63,7 +64,9 @@ define(function(require){
 			}
 			return { 'id' : this.model.id,
 					'policyType' : policyType.label,
-					'conditionType' : conditionType
+                                        'conditionType' : conditionType,
+          'policyTimeBtnLabel': (this.model.has('validitySchedules') && this.model.get('validitySchedules').length > 0) ? localization.tt('lbl.editValidityPeriod')
+                  : localization.tt('lbl.addValidityPeriod')
 				};
 		},
 		initialize: function(options) {
@@ -101,6 +104,7 @@ define(function(require){
 		ui : {
 			'denyConditionItems' : '[data-js="denyConditionItems"]',
 			'allowExcludePerm' : '[data-js="allowExcludePerm"]',
+      'policyTimeBtn'      : '[data-js="policyTimeBtn"]'
 		},
 		/** fields for the form
 		*/
@@ -110,22 +114,22 @@ define(function(require){
 		},
 		getSchema : function(){
 			var attrs = {},that = this;
-			var basicSchema = ['name','isEnabled'];
+                        var basicSchema = ['name','isEnabled','policyPriority','policyLabels'];
 			var schemaNames = this.getPolicyBaseFieldNames();
-			
+
 			var formDataType = new BackboneFormDataType();
 			attrs = formDataType.getFormElements(this.rangerServiceDefModel.get('resources'),this.rangerServiceDefModel.get('enums'), attrs, this, true);
-			
+
 			var attr1 = _.pick(_.result(this.model,'schemaBase'),basicSchema);
 			var attr2 = _.pick(_.result(this.model,'schemaBase'),schemaNames);
 			return _.extend(attr1,_.extend(attrs,attr2));
 		},
 		/** on render callback */
 		render: function(options) {
-                    var that = this;
+            var that = this;
 			Backbone.Form.prototype.render.call(this, options);
 			//initialize path plugin for hdfs component : resourcePath
-			if(!_.isUndefined(this.initilializePathPlugin) && this.initilializePathPlugin){ 
+                        if(!_.isUndefined(this.initilializePathPlugin) && this.initilializePathPlugin){
 				this.initializePathPlugins(this.pathPluginOpts);
 			}
 			this.renderCustomFields();
@@ -134,12 +138,56 @@ define(function(require){
 			}
 			//checkParent
 			this.renderParentChildHideShow();
-			
+
 			//to show error msg on below the field(only for policy name)
 			this.fields.isEnabled.$el.find('.control-label').removeClass();
 			this.fields.name.$el.find('.help-inline').removeClass('help-inline').addClass('help-block margin-left-5')
 			this.initializePlugins();
+                        this.setPolicyValidityTime();
+
 		},
+            setPolicyValidityTime : function(){
+              var that = this;
+              this.$el.find(this.ui.policyTimeBtn).on('click', function(e){
+                  var policyDirtyField = that.model.has('validitySchedules') ? new Backbone.Collection(that.model.get('validitySchedules')) : new Backbone.Collection();
+                  policyDirtyField.on('change',function(){
+                      that.$el.find('[data-js="policyTimeBtn"]').addClass('dirtyField');
+                  });
+                  var view = new vPolicyTimeList({
+                      collection: policyDirtyField,
+                      model : that.model
+                });
+                var modal = new Backbone.BootstrapModal({
+                  content	: view,
+                  title	: 'Policy Validity Period',
+                  okText  :"Save",
+                  animate : true,focusOk:false,
+                  escape:false,
+                  // allowCancel:false,
+                  modalOptions:{
+                    backdrop: 'static',
+                    keyboard: false
+                  },
+                }).open();
+
+                modal.$el.addClass('modal-policy-time');
+                $('body').addClass('hideBodyScroll')
+                //To prevent modal being close by click out of modal
+                modal.$el.find('.cancel, .close').on('click', function(e){
+                  modal._preventClose = false;
+                  $('body').removeClass('hideBodyScroll');
+                  $('[data-js="policyTimeBtn"]').addClass('dirtyField');
+                  $(".datetimepicker").remove();
+                });
+                modal.$el.find('.ok').on('click', function(e){
+                    modal._preventClose = false;
+                    $('body').removeClass('hideBodyScroll');
+                });
+                modal.on('shown', function(a){
+                  this.preventClose();
+                });
+              });
+            },
 		initializePlugins : function() {
 			var that = this;
 			this.$(".wrap-header").each(function(i, ele) {
@@ -246,13 +294,16 @@ define(function(require){
 						}*/
 						this.model.set(resourceDef.name, obj)
 					}
-				},this)
+                                },this);
 			}
 		},
 		setUpSwitches :function(){
 			var that = this;
 			this.fields.isAuditEnabled.editor.setValue(this.model.get('isAuditEnabled'));
 			this.fields.isEnabled.editor.setValue(this.model.get('isEnabled'));
+                    if(this.model.has('policyPriority')){
+                        this.fields.policyPriority.editor.setValue(this.model.get('policyPriority') == 1 ? true : false);
+                    }
 		},
 		/** all custom field rendering */
 		renderCustomFields: function(){
@@ -456,6 +507,9 @@ define(function(require){
 			}
 			this.model.set('service',this.rangerService.get('name'));
                         this.model.set('name', _.escape(this.model.get('name')));
+                        if(this.model.has('policyPriority')){
+                                this.model.set('policyPriority', this.model.get('policyPriority') ? 1 : 0);
+                        }
 		},
 		setPermissionsToColl : function(list, policyItemList) {
 			list.each(function(m){
@@ -506,77 +560,73 @@ define(function(require){
 			function extractLast( term ) {
 				return split( term ).pop();
 			}
-
-			this.fields[that.pathFieldName].editor.$el.find('[data-js="resource"]').tagit({
-				autocomplete : {
-					cache: false,
-					source: function( request, response ) {
-						var url = "service/plugins/services/lookupResource/"+that.rangerService.get('name');
-						var context ={
-							'userInput' : extractLast( request.term ),
-							'resourceName' : that.pathFieldName,
-							'resources' : {}
-						};
-						var val = that.fields[that.pathFieldName].editor.getValue();
-						context.resources[that.pathFieldName] = _.isNull(val) || _.isEmpty(val) ? [] : val.resource.split(","); 
-						var p = $.ajax({
-							url : url,
-							type : "POST",
-							data : JSON.stringify(context),
-							dataType : 'json',
-							contentType: "application/json; charset=utf-8",
-						}).done(function(data){
-							if(data){
-								response(data);
-							} else {
-								response();
-							}
-
-						}).error(function(){
-							response();
-
-						});
-						setTimeout(function(){ 
-							p.abort();
-							console.log('connection timeout for resource path request...!!');
-						}, 10000);
-					},
-					open : function(){
-						$(this).removeClass('working');
-					},
-					search: function() {
-						if(!_.isUndefined(this.value) && _.contains(this.value,',')){ 
-							_.each(this.value.split(',') , function(tag){
-								that.fields[that.pathFieldName].editor.$el.tagit("createTag", tag);
-							});
-				        	return false;
-				        }	
-						var term = extractLast( this.value );
-						$(this).addClass('working');
-						if ( term.length < 1 ) {
-							return false;
-						}
-					},
-					
-				},
-				beforeTagAdded: function(event, ui) {
-			        // do something special
-					that.fields[that.pathFieldName].$el.removeClass('error');
-		        	that.fields[that.pathFieldName].$el.find('.help-inline').html('');
-					var tags =  [];
-			        console.log(ui.tag);
-			        if(!_.isUndefined(options.regExpValidation) && !options.regExpValidation.regexp.test(ui.tagLabel)){
-			        	that.fields[that.pathFieldName].$el.addClass('error');
-			        	that.fields[that.pathFieldName].$el.find('.help-inline').html(options.regExpValidation.message);
-			        	return false;
-			        }
-				}
-			}).on('change',function(e){
-				//check dirty field for tagit input type : `path`
-				XAUtil.checkDirtyField($(e.currentTarget).val(), defaultValue.toString(), $(e.currentTarget))
-			});
-	
-			
+                        var tagitOpts = {}
+                        if(!_.isUndefined(options.lookupURL) && options.lookupURL){
+                            tagitOpts["autocomplete"] = {
+                            cache: false,
+                    source: function( request, response ) {
+                        var url = "service/plugins/services/lookupResource/"+that.rangerService.get('name');
+                        var context ={
+                            'userInput' : extractLast( request.term ),
+                            'resourceName' : that.pathFieldName,
+                            'resources' : {}
+                        };
+                        var val = that.fields[that.pathFieldName].editor.getValue();
+                        context.resources[that.pathFieldName] = _.isNull(val) || _.isEmpty(val) ? [] : val.resource.split(",");
+                        var p = $.ajax({
+                            url : url,
+                            type : "POST",
+                            data : JSON.stringify(context),
+                            dataType : 'json',
+                            contentType: "application/json; charset=utf-8",
+                        }).done(function(data){
+                            if(data){
+                                response(data);
+                            } else {
+                                response();
+                            }
+                        }).fail(function(){
+                            response();
+                        });
+                        setTimeout(function(){
+                            p.abort();
+                            console.log('connection timeout for resource path request...!!');
+                        }, 10000);
+                    },
+                    open : function(){
+                        $(this).removeClass('working');
+                    },
+                    search: function() {
+                        if(!_.isUndefined(this.value) && _.contains(this.value,',')){
+                            _.each(this.value.split(',') , function(tag){
+                                that.fields[that.pathFieldName].editor.$el.tagit("createTag", tag);
+                            });
+                            return false;
+                        }
+                        var term = extractLast( this.value );
+                        $(this).addClass('working');
+                        if ( term.length < 1 ) {
+                            return false;
+                        }
+                    },
+                            }
+                        }
+                        tagitOpts['beforeTagAdded'] = function(event, ui) {
+                // do something special
+                that.fields[that.pathFieldName].$el.removeClass('error');
+                that.fields[that.pathFieldName].$el.find('.help-inline').html('');
+                var tags =  [];
+                console.log(ui.tag);
+                if(!_.isUndefined(options.regExpValidation) && !options.regExpValidation.regexp.test(ui.tagLabel)){
+                    that.fields[that.pathFieldName].$el.addClass('error');
+                    that.fields[that.pathFieldName].$el.find('.help-inline').html(options.regExpValidation.message);
+                    return false;
+                }
+            }
+            this.fields[that.pathFieldName].editor.$el.find('[data-js="resource"]').tagit(tagitOpts).on('change', function(e){
+                //check dirty field for tagit input type : `path`
+                XAUtil.checkDirtyField($(e.currentTarget).val(), defaultValue.toString(), $(e.currentTarget));
+            });
 		},
 		getPlugginAttr :function(autocomplete, options){
 			var that =this, type = options.containerCssClass, validRegExpString = true, select2Opts=[];
@@ -647,7 +697,7 @@ define(function(require){
 							};
 						},
 						transport: function (options) {
-							$.ajax(options).error(function() { 
+                                                        $.ajax(options).fail(function() {
 								console.log("ajax failed");
 								this.success({
 									resultSize : 0
@@ -766,8 +816,7 @@ define(function(require){
 			return obj;
 		},
 		getPolicyBaseFieldNames : function(){
-                    var fields = ['isAuditEnabled','description','policyLabels'];
-			 return fields;
+                        return ['description','isAuditEnabled'];
 		},
 		getResources : function(){
 			if(XAUtil.isMaskingPolicy(this.model.get('policyType'))){
@@ -784,6 +833,5 @@ define(function(require){
 			return this.rangerServiceDefModel.get('resources');
 		},
 	});
-
 	return RangerPolicyForm;
 });
