@@ -36,7 +36,7 @@ define(function(require){
 	var RangerServiceDef	= require('models/RangerServiceDef');
 	var RangerPolicy 		= require('models/RangerPolicy');
 	var RangerPolicyTableLayoutTmpl = require('hbs!tmpl/policies/RangerPolicyTableLayout_tmpl');
-	var RangerPolicyDetail			= require('views/policies/RangerPolicyDetail');
+        var RangerPolicyRO				= require('views/policies/RangerPolicyRO');
 
 	require('backgrid-filter');
 	require('backgrid-paginator');
@@ -55,7 +55,8 @@ define(function(require){
 				rangerServiceDef : this.rangerServiceDefModel,
 				rangerPolicyType : this.collection.queryParams['policyType'],
 				isRenderAccessTab : XAUtil.isRenderMasking(this.rangerServiceDefModel.get('dataMaskDef')) ? true 
-						  : XAUtil.isRenderRowFilter(this.rangerServiceDefModel.get('rowFilterDef')) ? true : false
+                                        : XAUtil.isRenderRowFilter(this.rangerServiceDefModel.get('rowFilterDef')) ? true : false,
+                isNotAuditorAdminOrKmsAuditor : !(XAUtil.isAuditorOrKMSAuditor(SessionMgr))
 			};
 		},
         
@@ -100,10 +101,7 @@ define(function(require){
 		*/
 		initialize: function(options) {
 			console.log("initialized a RangerPolicyTableLayout Layout");
-
 			_.extend(this, _.pick(options,'rangerService'));
-			
-			
 			this.bindEvents();
 			this.initializeServiceDef();
 		},
@@ -182,9 +180,11 @@ define(function(require){
 			rangerPolicy.fetch({
 				cache : false,
 			}).done(function(){
-				var view = new RangerPolicyDetail({
+				var policyVersionList = rangerPolicy.fetchVersions();
+				var view = new RangerPolicyRO({
 					model : rangerPolicy,
-					rangerService: that.rangerService
+					policyVersionList : policyVersionList,
+					rangerService: that.rangerServiceDefModel
 				});
 				var modal = new Backbone.BootstrapModal({
 					animate : true,
@@ -194,7 +194,14 @@ define(function(require){
 					allowCancel : true,
 					escape 	: true
 				}).open();
-				modal.$el.addClass('modal-diff').attr('tabindex',-1);
+				var policyVerEl = modal.$el.find('.modal-footer').prepend('<div class="policyVer pull-left"></div>').find('.policyVer');
+				policyVerEl.append('<i id="preVer" class="icon-chevron-left ' + ((rangerPolicy.get('version') > 1) ? 'active' : '') + '"></i><text>Version ' + rangerPolicy.get('version') + '</text>').find('#preVer').click(function(e) {
+					view.previousVer(e);
+				});
+				var policyVerIndexAt = policyVersionList.indexOf(rangerPolicy.get('version').toString());
+				policyVerEl.append('<i id="nextVer" class="icon-chevron-right ' + (!_.isUndefined(policyVersionList[++policyVerIndexAt]) ? 'active' : '') + '"></i>').find('#nextVer').click(function(e) {
+					view.nextVer(e);
+				});
 				modal.$el.find('.cancel').hide();
 			});
 		},
@@ -203,11 +210,35 @@ define(function(require){
 			var that = this;
 			var cols = {
 				id : {
-					cell : "uri",
-					href: function(model){
-						return '#!/service/'+that.rangerService.id+'/policies/'+model.id+'/edit';
-					},
+                    cell : 'html',
 					label	: localization.tt("lbl.policyId"),
+                    formatter: _.extend({}, Backgrid.CellFormatter.prototype, {
+                        fromRaw: function (rawValue, model) {
+                            if(XAUtil.isAuditorOrKMSAuditor(SessionMgr)){
+                                if(!_.isEmpty(model.get('validitySchedules')) && XAUtil.isPolicyExpierd(model)){
+                                    return '<div class="expiredIconPosition">\
+                                                <i class="icon-exclamation-sign backgrigModelId" title="Policy expired"></i>\
+                                                '+model.id+'\
+                                             </div>';
+                                }else{
+                                    return '<div class="expiredIconPosition">\
+                                                '+model.id+'\
+                                            </div>';
+                                }
+                            }else{
+                                if(!_.isEmpty(model.get('validitySchedules')) && XAUtil.isPolicyExpierd(model)){
+                                    return '<div class="expiredIconPosition">\
+                                                <i class="icon-exclamation-sign backgrigModelId" title="Policy expired"></i>\
+                                                <a class="" href="#!/service/'+that.rangerService.id+'/policies/'+model.id+'/edit">'+model.id+'</a>\
+                                             </div>';
+                                }else{
+                                    return '<div class="expiredIconPosition">\
+                                                <a class="" href="#!/service/'+that.rangerService.id+'/policies/'+model.id+'/edit">'+model.id+'</a>\
+                                            </div>';
+                                }
+                            }
+                        }
+                    }),
 					editable: false,
 					sortable : false
 				},
@@ -287,16 +318,19 @@ define(function(require){
 					sortable : false
 				},
 			};
-
 			cols['permissions'] = {
 				cell :  "html",
 				label : localization.tt("lbl.action"),
 				formatter: _.extend({}, Backgrid.CellFormatter.prototype, {
 					fromRaw: function (rawValue,model) {
-						return '<a href="javascript:void(0);" data-name ="viewPolicy" data-id="'+model.id+'" class="btn btn-mini" title="View"><i class="icon-eye-open icon-large" /></a>\
-								<a href="#!/service/'+that.rangerService.id+'/policies/'+model.id+'/edit" class="btn btn-mini" title="Edit"><i class="icon-edit icon-large" /></a>\
-								<a href="javascript:void(0);" data-name ="deletePolicy" data-id="'+model.id+'"  class="btn btn-mini btn-danger" title="Delete"><i class="icon-trash icon-large" /></a>';
+                        if(XAUtil.isAuditorOrKMSAuditor(SessionMgr)){
+                            return '<a href="javascript:void(0);" data-name ="viewPolicy" data-id="'+model.id+'" class="btn btn-mini" title="View"><i class="icon-eye-open icon-large" /></a>';
+                        }else{
+                            return '<a href="javascript:void(0);" data-name ="viewPolicy" data-id="'+model.id+'" class="btn btn-mini" title="View"><i class="icon-eye-open icon-large" /></a>\
+                                    <a href="#!/service/'+that.rangerService.id+'/policies/'+model.id+'/edit" class="btn btn-mini" title="Edit"><i class="icon-edit icon-large" /></a>\
+                                    <a href="javascript:void(0);" data-name ="deletePolicy" data-id="'+model.id+'"  class="btn btn-mini btn-danger" title="Delete"><i class="icon-trash icon-large" /></a>';
 						//You can use rawValue to custom your html, you can change this value using the name parameter.
+                        }
 					}
 				}),
 				editable: false,
@@ -395,12 +429,14 @@ define(function(require){
                         var info = { collection : localization.tt('h.collection')    , column   :localization.tt('lbl.columnName'),
                                          'column-family':localization.tt('msg.columnfamily') , database :localization.tt('h.database'),
                                           entity        :localization.tt('h.entity') , keyname  :localization.tt('lbl.keyName'),
-                                          operation:localization.tt('h.operation')   , path:localization.tt('h.path') ,
-                                          queue:localization.tt('h.queue')        , service:localization.tt('h.serviceNameMsg'),
-                                          table:localization.tt('lbl.tableName')   , tag : localization.tt('h.tagsMsg'),
-                                          taxonomy:localization.tt('h.taxonomy')  ,term: localization.tt('h.term') ,
+                                          path:localization.tt('h.path'), queue: localization.tt('h.queue'), service:localization.tt('h.serviceNameMsg'),
+                                          table:localization.tt('lbl.tableName'), tag : localization.tt('h.tagsMsg'),
                                           topic:localization.tt('h.topic')    ,topology:localization.tt('lbl.topologyName'),
-                                          type:localization.tt('h.type')    ,udf:localization.tt('h.udf') , url:localization.tt('h.url')
+                                          type:localization.tt('h.type')    ,udf:localization.tt('h.udf') , url:localization.tt('h.url'),
+                                          'type-category': localization.tt('h.typeCategory'), 'entity-type': localization.tt('h.entityType'),
+                                          'entity-classification': localization.tt('h.entityClassification'), 'atlas-service': localization.tt('h.atlasService'),
+                                          connector: localization.tt('h.connector'), link: localization.tt('h.link'), job: localization.tt('h.job'),
+                                          project: localization.tt('h.project'), 'nifi-resource': localization.tt('h.nifiResource')
                                                  };
 			var serverRsrcAttrName = _.map(resourceSearchOpt,function(opt){ 
                                         return {
@@ -477,7 +513,7 @@ define(function(require){
 		},
 		/** on close */
 		onClose: function(){
-                        $('.popover').remove();
+            XAUtil.removeUnwantedDomElement();
 		}
 
 	});
