@@ -53,6 +53,8 @@ import org.apache.commons.collections.BidiMap;
 import org.apache.commons.collections.bidimap.DualHashBidiMap;
 import org.apache.log4j.Logger;
 import org.apache.ranger.unixusersync.config.UserGroupSyncConfig;
+import org.apache.ranger.unixusersync.model.LdapSyncSourceInfo;
+import org.apache.ranger.unixusersync.model.UgsyncAuditInfo;
 import org.apache.ranger.usergroupsync.AbstractUserGroupSource;
 import org.apache.ranger.usergroupsync.UserGroupSink;
 
@@ -116,7 +118,14 @@ public class LdapDeltaUserGroupBuilder extends AbstractUserGroupSource {
 
   private Table<String, String, String> groupUserTable;
   private Map<String, String> userNameMap;
+	private HashSet<String> groupNames;
 	private BidiMap groupNameMap;
+	UgsyncAuditInfo ugsyncAuditInfo;
+	LdapSyncSourceInfo ldapSyncSourceInfo;
+	int noOfNewUsers;
+	int noOfNewGroups;
+	int noOfModifiedUsers;
+	int noOfModifiedGroups;
 
 	public static void main(String[] args) throws Throwable {
 		LdapDeltaUserGroupBuilder  ugBuilder = new LdapDeltaUserGroupBuilder();
@@ -156,7 +165,18 @@ public class LdapDeltaUserGroupBuilder extends AbstractUserGroupSource {
 		deltaSyncUserTimeStamp = dateFormat.format(new Date(0));
 		deltaSyncGroupTimeStamp = dateFormat.format(new Date(0));
 		userNameMap = new HashMap<String, String>();
+		groupNames = new HashSet<String>();
 		setConfig();
+		ugsyncAuditInfo = new UgsyncAuditInfo();
+		ldapSyncSourceInfo = new LdapSyncSourceInfo();
+		ldapSyncSourceInfo.setLdapUrl(ldapUrl);
+		ldapSyncSourceInfo.setIncrementalSycn("True");
+		ldapSyncSourceInfo.setUserSearchEnabled(Boolean.toString(userSearchEnabled));
+		ldapSyncSourceInfo.setGroupSearchEnabled(Boolean.toString(groupSearchEnabled));
+		ldapSyncSourceInfo.setGroupSearchFirstEnabled(Boolean.toString(groupSearchFirstEnabled));
+		ldapSyncSourceInfo.setGroupHierarchyLevel(Integer.toString(groupHierarchyLevels));
+		ugsyncAuditInfo.setSyncSource("LDAP/AD");
+		ugsyncAuditInfo.setLdapSyncSourceInfo(ldapSyncSourceInfo);
 	}
 
 	private void createLdapContext() throws Throwable {
@@ -303,9 +323,13 @@ public class LdapDeltaUserGroupBuilder extends AbstractUserGroupSource {
 	@Override
 	public void updateSink(UserGroupSink sink) throws Throwable {
 		LOG.info("LdapDeltaUserGroupBuilder updateSink started");
-		//userGroupMap = new HashMap<String, UserInfo>();
 		groupUserTable = HashBasedTable.create();
         groupNameMap = new DualHashBidiMap();
+		noOfNewUsers = 0;
+		noOfNewGroups = 0;
+		noOfModifiedUsers = 0;
+		noOfModifiedGroups = 0;
+
         if (!groupSearchFirstEnabled) {
 			LOG.info("Performing user search first");
 			getUsers(sink);
@@ -324,6 +348,17 @@ public class LdapDeltaUserGroupBuilder extends AbstractUserGroupSource {
 		}
 		if (groupUserTable.isEmpty()) {
 			//System.out.println("groupUserTable is empty!!");
+			ugsyncAuditInfo.setNoOfNewUsers(Integer.toUnsignedLong(noOfNewUsers));
+			ugsyncAuditInfo.setNoOfNewGroups(Integer.toUnsignedLong(noOfNewGroups));
+			ugsyncAuditInfo.setNoOfModifiedUsers(Integer.toUnsignedLong(noOfModifiedUsers));
+			ugsyncAuditInfo.setNoOfModifiedGroups(Integer.toUnsignedLong(noOfModifiedGroups));
+			ldapSyncSourceInfo.setUserSearchFilter(extendedUserSearchFilter);
+			ldapSyncSourceInfo.setGroupSearchFilter(extendedAllGroupsSearchFilter);
+			try {
+				sink.postUserGroupAuditInfo(ugsyncAuditInfo);
+			} catch (Throwable t) {
+				LOG.error("sink.postUserGroupAuditInfo failed with exception: " + t.getMessage());
+			}
 			return;
 		}
         
@@ -358,6 +393,22 @@ public class LdapDeltaUserGroupBuilder extends AbstractUserGroupSource {
 				+ ", users: " + userList);
 			}
 		}
+		LOG.debug("postUserGroupAuditInfo(): noOfUsers = " + noOfNewUsers + " noOfGroups = " + noOfNewGroups);
+
+		ugsyncAuditInfo.setNoOfNewUsers(Integer.toUnsignedLong(noOfNewUsers));
+		ugsyncAuditInfo.setNoOfNewGroups(Integer.toUnsignedLong(noOfNewGroups));
+		ugsyncAuditInfo.setNoOfModifiedUsers(Integer.toUnsignedLong(noOfModifiedUsers));
+		ugsyncAuditInfo.setNoOfModifiedGroups(Integer.toUnsignedLong(noOfModifiedGroups));
+		ldapSyncSourceInfo.setUserSearchFilter(extendedUserSearchFilter);
+		ldapSyncSourceInfo.setGroupSearchFilter(extendedAllGroupsSearchFilter);
+		ldapSyncSourceInfo.setTotalUsersSynced(userNameMap.size());
+		ldapSyncSourceInfo.setTotalGroupsSynced(groupNames.size());
+
+		try {
+			sink.postUserGroupAuditInfo(ugsyncAuditInfo);
+		} catch (Throwable t) {
+			LOG.error("sink.postUserGroupAuditInfo failed with exception: " + t.getMessage());
+		}
 	}
 
 	private void getUsers(UserGroupSink sink) throws Throwable {
@@ -477,6 +528,11 @@ public class LdapDeltaUserGroupBuilder extends AbstractUserGroupSource {
 								+ ", for user: " + transformUserName);
 							}
 							//System.out.println("Adding user fullname = " + userFullName + " username = " + transformUserName);
+							if (userNameMap.containsKey(userFullName)) {
+								noOfModifiedUsers++;
+							} else {
+								noOfNewUsers++;
+							}
 							userNameMap.put(userFullName, transformUserName);
 							Set<String> groups = new HashSet<String>();
 
@@ -509,24 +565,29 @@ public class LdapDeltaUserGroupBuilder extends AbstractUserGroupSource {
 							// If the user from the search result is present in the group user table,
 							// then addorupdate user to ranger admin.
 							LOG.debug("Chekcing if the user " + userFullName + " is part of the retrieved groups");
-							if ((groupUserTable.containsColumn(userFullName) || groupUserTable.containsColumn(userName))
-									&& !userNameMap.containsKey(userFullName)) {
-								String transformUserName = userNameTransform(userName);
-								try {
-									sink.addOrUpdateUser(transformUserName);
-								} catch (Throwable t) {
-									LOG.error("sink.addOrUpdateUser failed with exception: " + t.getMessage()
-									+ ", for user: " + transformUserName);
+							if ((groupUserTable.containsColumn(userFullName) || groupUserTable.containsColumn(userName))) {
+								if (!userNameMap.containsKey(userFullName)) {
+									String transformUserName = userNameTransform(userName);
+									try {
+										sink.addOrUpdateUser(transformUserName);
+									} catch (Throwable t) {
+										LOG.error("sink.addOrUpdateUser failed with exception: " + t.getMessage()
+												+ ", for user: " + transformUserName);
+									}
+									userNameMap.put(userFullName, transformUserName);
+									//Also update the username in the groupUserTable with the one from username attribute.
+									Map<String, String> userMap = groupUserTable.column(userFullName);
+									for (Map.Entry<String, String> entry : userMap.entrySet()) {
+										LOG.debug("Updating groupUserTable " + entry.getValue() + " with: " + transformUserName + " for " + entry.getKey());
+										groupUserTable.put(entry.getKey(), userFullName, transformUserName);
+									}
+									counter++;
+									noOfNewUsers++;
+								} else {
+									noOfModifiedUsers++;
 								}
-								userNameMap.put(userFullName, transformUserName);
-								//Also update the username in the groupUserTable with the one from username attribute.
-								Map<String,String> userMap =  groupUserTable.column(userFullName);
-								for(Map.Entry<String, String> entry : userMap.entrySet()){
-									LOG.debug("Updating groupUserTable " + entry.getValue() + " with: " + transformUserName + " for " + entry.getKey());
-									groupUserTable.put(entry.getKey(), userFullName, transformUserName);
-								}
-                                counter++;
 							}
+
 						}
 
                         if (counter <= 2000) {
@@ -660,6 +721,7 @@ public class LdapDeltaUserGroupBuilder extends AbstractUserGroupSource {
 								LOG.debug("Update Ranger admin with " + transformGroupName);
 								sink.addOrUpdateGroup(transformGroupName);
 							}
+
 							Attribute timeStampAttr  = groupEntry.getAttributes().get("uSNChanged");
 							if (timeStampAttr != null) {
 								String uSNChangedVal = (String) timeStampAttr.get();
@@ -684,6 +746,14 @@ public class LdapDeltaUserGroupBuilder extends AbstractUserGroupSource {
 							int userCount = 0;
 							if (groupMemberAttr == null || groupMemberAttr.size() <= 0) {
 								LOG.info("No members available for " + gName);
+								if (groupSearchFirstEnabled) {
+									if (groupNames.contains(gName)) {
+										noOfModifiedGroups++;
+									} else {
+										noOfNewGroups++;
+									}
+									groupNames.add(gName);
+								}
 								continue;
 							}
 
@@ -704,6 +774,11 @@ public class LdapDeltaUserGroupBuilder extends AbstractUserGroupSource {
 										LOG.error("sink.addOrUpdateUser failed with exception: " + t.getMessage()
 										+ ", for user: " + transformUserName);
 									}
+									if (userNameMap.containsKey(originalUserFullName)) {
+										noOfModifiedUsers++;
+									} else {
+										noOfNewUsers++;
+									}
 									userNameMap.put(originalUserFullName, transformUserName);
 								}
 								//System.out.println("Adding " + userNameMap.get(originalUserFullName) + " and fullname = " + originalUserFullName + " to " + gName);
@@ -714,6 +789,12 @@ public class LdapDeltaUserGroupBuilder extends AbstractUserGroupSource {
 								}
                                 groupNameMap.put(groupEntry.getNameInNamespace().toLowerCase(), gName);
 							}
+							if (groupNames.contains(gName)) {
+								noOfModifiedGroups++;
+							} else {
+								noOfNewGroups++;
+							}
+							groupNames.add(gName);
 							LOG.info("No. of members in the group " + gName + " = " + userCount);
 						}
 						// Examine the paged results control response
@@ -770,7 +851,7 @@ public class LdapDeltaUserGroupBuilder extends AbstractUserGroupSource {
             // Incrementing highestdeltaSyncGroupTime (for AD) in order to avoid search record repetition for next sync cycle.
             deltaSyncGroupTime = highestdeltaSyncGroupTime+1;
             // Incrementing the highest timestamp value (for OpenLdap) with 1min in order to avoid search record repetition for next sync cycle.
-            deltaSyncGroupTimeStamp = dateFormat.format(new Date(highestdeltaSyncGroupTime + 60000l));
+            deltaSyncGroupTimeStamp = dateFormat.format(new Date(highestdeltaSyncGroupTime + 60l));
         }
 	}
 
@@ -855,6 +936,7 @@ public class LdapDeltaUserGroupBuilder extends AbstractUserGroupSource {
 
 			// Add all members of sub group to the parent groups if the member is not a group in turn
 			Set<String> allMembers = groupUserTable.row(groupSName).keySet();
+			LOG.info("members of " + groupSName + " = " + allMembers);
 			for(String member : allMembers) {
 				String memberName = getShortGroupName(member);
 				if (!groupUserTable.containsRow(memberName)) { //Check if the member of a group is in turn a group
