@@ -47,6 +47,8 @@ import javax.naming.ldap.StartTlsResponse;
 
 import org.apache.log4j.Logger;
 import org.apache.ranger.unixusersync.config.UserGroupSyncConfig;
+import org.apache.ranger.unixusersync.model.LdapSyncSourceInfo;
+import org.apache.ranger.unixusersync.model.UgsyncAuditInfo;
 import org.apache.ranger.usergroupsync.AbstractUserGroupSource;
 import org.apache.ranger.usergroupsync.UserGroupSink;
 
@@ -101,6 +103,10 @@ public class LdapUserGroupBuilder extends AbstractUserGroupSource {
 
 	private Map<String, UserInfo> userGroupMap;
     //private Set<String> firstGroupDNs;
+	private Set<String> allUsers;
+
+	UgsyncAuditInfo ugsyncAuditInfo;
+	LdapSyncSourceInfo ldapSyncSourceInfo;
 
 	public static void main(String[] args) throws Throwable {
 		LdapUserGroupBuilder  ugBuilder = new LdapUserGroupBuilder();
@@ -135,6 +141,16 @@ public class LdapUserGroupBuilder extends AbstractUserGroupSource {
 	@Override
 	public void init() throws Throwable{
 		setConfig();
+		ugsyncAuditInfo = new UgsyncAuditInfo();
+		ldapSyncSourceInfo = new LdapSyncSourceInfo();
+		ldapSyncSourceInfo.setLdapUrl(ldapUrl);
+		ldapSyncSourceInfo.setIncrementalSycn("False");
+		ldapSyncSourceInfo.setUserSearchEnabled(Boolean.toString(userSearchEnabled));
+		ldapSyncSourceInfo.setGroupSearchEnabled(Boolean.toString(groupSearchEnabled));
+		ldapSyncSourceInfo.setGroupSearchFirstEnabled(Boolean.toString(groupSearchFirstEnabled));
+		ldapSyncSourceInfo.setGroupHierarchyLevel(Integer.toString(groupHierarchyLevels));
+		ugsyncAuditInfo.setSyncSource("LDAP/AD");
+		ugsyncAuditInfo.setLdapSyncSourceInfo(ldapSyncSourceInfo);
 	}
 
 	private void createLdapContext() throws Throwable {
@@ -299,6 +315,8 @@ public class LdapUserGroupBuilder extends AbstractUserGroupSource {
 	public void updateSink(UserGroupSink sink) throws Throwable {
 		LOG.info("LDAPUserGroupBuilder updateSink started");
 		userGroupMap = new HashMap<String, UserInfo>();
+		Set<String> allGroups = new HashSet<String>();
+		allUsers = new HashSet<String>();
 
 		if (!groupSearchFirstEnabled) {
 			LOG.info("Performing user search first");
@@ -322,6 +340,7 @@ public class LdapUserGroupBuilder extends AbstractUserGroupSource {
                     LOG.debug("Completed group hierarchy computation");
                 }
 				List<String> groupList = userInfo.getGroups();
+				allGroups.addAll(groupList);
                 LOG.debug("updateSink(): group list for " + userName + " = " + groupList);
 				if (userNameCaseConversionFlag) {
 					if (userNameLowerCaseFlag) {
@@ -343,24 +362,37 @@ public class LdapUserGroupBuilder extends AbstractUserGroupSource {
 					+ ", groups: " + groupList);
 				}
 			}
+			ldapSyncSourceInfo.setUserSearchFilter(extendedUserSearchFilter);
+			ldapSyncSourceInfo.setGroupSearchFilter(extendedAllGroupsSearchFilter);
+			ldapSyncSourceInfo.setTotalUsersSynced(allUsers.size());
+			ldapSyncSourceInfo.setTotalGroupsSynced(allGroups.size());
+			try {
+				sink.postUserGroupAuditInfo(ugsyncAuditInfo);
+			} catch (Throwable t) {
+				LOG.error("sink.postUserGroupAuditInfo failed with exception: " + t.getMessage());
+			}
 
 		} else {
 			LOG.info("Performing Group search first");
 			getGroups(sink, null);
-            // Go through the userInfo map and update ranger admin.
+			 // Go through the userInfo map and update ranger admin.
             for (UserInfo userInfo : userGroupMap.values()) {
+				LOG.debug("userName from map = " + userInfo.getUserFullName());
                 String userName = getShortUserName(userInfo.getUserFullName());
                 if (groupHierarchyLevels > 0) {
                     //System.out.println("Going through group hierarchy for nested group evaluation");
                     goUpGroupHierarchyLdap(userInfo.getGroupDNs(), groupHierarchyLevels - 1, userInfo);
                     //System.out.println("Completed group hierarchy computation");
                 }
+				List<String> groupList = userInfo.getGroups();
+				allGroups.addAll(groupList);
                 if (userSearchEnabled) {
                     LOG.info("User search is enabled and hence computing user membership.");
                     getUsers(sink);
                 } else {
                     LOG.info("User search is disabled and hence using the group member attribute for username" + userName);
-                    List<String> groupList = userInfo.getGroups();
+					allGroups.addAll(groupList);
+					allUsers.add(userName); // Note:- in this case the usernames may contain groups as part of nested groups
                     if (userNameCaseConversionFlag) {
                         if (userNameLowerCaseFlag) {
                             userName = userName.toLowerCase();
@@ -382,6 +414,15 @@ public class LdapUserGroupBuilder extends AbstractUserGroupSource {
                     }
                 }
             }
+			ldapSyncSourceInfo.setUserSearchFilter(extendedUserSearchFilter);
+			ldapSyncSourceInfo.setGroupSearchFilter(extendedAllGroupsSearchFilter);
+			ldapSyncSourceInfo.setTotalUsersSynced(allUsers.size());
+			ldapSyncSourceInfo.setTotalGroupsSynced(allGroups.size());
+			try {
+				sink.postUserGroupAuditInfo(ugsyncAuditInfo);
+			} catch (Throwable t) {
+				LOG.error("sink.postUserGroupAuditInfo failed with exception: " + t.getMessage());
+			}
 		}
 	}
 
@@ -487,6 +528,7 @@ public class LdapUserGroupBuilder extends AbstractUserGroupSource {
 									LOG.warn("user object with username " + userName + " already exists and is replaced with the latest user object." );
 								}
 								userGroupMap.put(userName, userInfo);
+								allUsers.add(userName);
 
 								//List<String> groupList = new ArrayList<String>(groups);
 								List<String> groupList = userInfo.getGroups();
@@ -526,6 +568,7 @@ public class LdapUserGroupBuilder extends AbstractUserGroupSource {
 									counter++;
 									LOG.info("Updating username for " + userFullName + " with " + userName);
 									userInfo.updateUserName(userName);
+									allUsers.add(userName);
                                     List<String> groupList = userInfo.getGroups();
                                     if (userNameCaseConversionFlag) {
                                         if (userNameLowerCaseFlag) {
@@ -675,12 +718,13 @@ public class LdapUserGroupBuilder extends AbstractUserGroupSource {
 									// check for group members and populate userInfo object with user's full name and group mapping
 									Attribute groupMemberAttr = groupEntry.getAttributes().get(groupMemberAttributeName);
 									LOG.debug("Update Ranger admin with " + gName);
-									sink.addOrUpdateGroup(gName);
 									int userCount = 0;
 									if (groupMemberAttr == null || groupMemberAttr.size() <= 0) {
 										LOG.info("No members available for " + gName);
+										sink.addOrUpdateGroup(gName, null);
 										continue;
 									}
+									sink.addOrUpdateGroup(gName);
 									NamingEnumeration<?> userEnum = groupMemberAttr.getAll();
 									while (userEnum.hasMore()) {
 										String originalUserFullName = (String) userEnum.next();
