@@ -18,15 +18,12 @@ import re
 import StringIO
 import xml.etree.ElementTree as ET
 import ConfigParser
-import os, errno, sys, getopt
-import sys
-from os import listdir
+import os, sys
 from os.path import isfile, join, dirname, basename
-from urlparse import urlparse
-from time import gmtime, strftime, localtime
-from xml import etree
+from time import strftime, localtime
 import shutil
 import pwd, grp
+import commands
 
 globalDict = {}
 
@@ -280,11 +277,14 @@ def convertInstallPropsToXML(props):
 
 
 def createUser(username, groupname):
-    cmd = "useradd -g %s %s -m" % (groupname, username)
-    ret = os.system(cmd)
-    if (ret != 0):
-        print "ERROR: os command execution (%s) failed. error code = %d " % (cmd, ret)
-        sys.exit(1)
+    checkuser = "grep ^" + username + ": /etc/passwd | awk -F: '{print $1}'|head -1 "
+    (status, output) = commands.getstatusoutput(checkuser)
+    if len(output) < 1:
+        cmd = "useradd -g %s %s -m" % (groupname, username)
+        ret = os.system(cmd)
+        if (ret != 0):
+            print "ERROR: os command execution (%s) failed. error code = %d " % (cmd, ret)
+            sys.exit(1)
     try:
         ret = pwd.getpwnam(username).pw_uid
         return ret
@@ -294,11 +294,14 @@ def createUser(username, groupname):
 
 
 def createGroup(groupname):
-    cmd = "groupadd %s" % (groupname)
-    ret = os.system(cmd)
-    if (ret != 0):
-        print "ERROR: os command execution (%s) failed. error code = %d " % (cmd, ret)
-        sys.exit(1)
+    checkgroup = "egrep ^" + groupname + ": /etc/group | awk -F: '{print $1}'|head -1 "
+    (status, output) = commands.getstatusoutput(checkgroup)
+    if len(output) < 1:
+        cmd = "groupadd %s" % (groupname)
+        ret = os.system(cmd)
+        if (ret != 0):
+            print "ERROR: os command execution (%s) failed. error code = %d " % (cmd, ret)
+            sys.exit(1)
     try:
         ret = grp.getgrnam(groupname).gr_gid
         return ret
